/*****************************************************************************/

/*
 *      afsk_firmware.h  -- HDLC packet radio modem for EPP using FPGA utility.
 *
 *      Copyright (C) 1998  Thomas Sailer (sailer@ife.ee.ethz.ch)
 *
 *      This program is free software; you can redistribute it and/or modify
 *      it under the terms of the GNU General Public License as published by
 *      the Free Software Foundation; either version 2 of the License, or
 *      (at your option) any later version.
 *
 *      This program is distributed in the hope that it will be useful,
 *      but WITHOUT ANY WARRANTY; without even the implied warranty of
 *      MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *      GNU General Public License for more details.
 *
 *      You should have received a copy of the GNU General Public License
 *      along with this program; if not, write to the Free Software
 *      Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 *  Please note that the GPL allows you to use the driver, NOT the radio.
 *  In order to use the radio, you need a license from the communications
 *  authority of your country.
 *
 */

/*****************************************************************************/
/* automatically generated, do not edit */

#define AFSK_FIRMWAREDATE "20001009"

/* firmware */
static const unsigned char afsk_firmware[] = {
	0xff, 0x04, 0xe8, 0x8c, 0xf9, 0xee, 0x7f, 0xff, 
	0xfd, 0xe5, 0xd7, 0x5f, 0x7e, 0xfd, 0xed, 0xbf, 
	0xef, 0xfe, 0xf2, 0xee, 0xad, 0xbf, 0xfe, 0xf6, 
	0xfb, 0x9b, 0xff, 0xff, 0xaf, 0xff, 0xff, 0xfb, 
	0xff, 0xbf, 0xff, 0xff, 0xfe, 0xdf, 0xff, 0xff, 
	0x7d, 0xf7, 0xdf, 0xff, 0xff, 0xff, 0xe6, 0xff, 
	0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 
	0xff, 0xff, 0xff, 0xff, 0xff, 0xbf, 0xff, 0xff, 
	0xff, 0xff, 0xbf, 0xf9, 0xff, 0xf8, 0xed, 0xbf, 
	0xff, 0xfe, 0xfb, 0xef, 0xbf, 0x5f, 0xfc, 0xf7, 
	0xdf, 0x7f, 0xff, 0xfd, 0xf7, 0xe7, 0xff, 0x6f, 
	0xfe, 0xfb, 0xc6, 0x5f, 0x6f, 0xfd, 0xf5, 0xd6, 
	0x5f, 0x7f, 0x7d, 0xe3, 0xaf, 0x37, 0xfe, 0xfa, 
	0xeb, 0xaf, 0xbd, 0xfe, 0x9b, 0xf3, 0x5f, 0xe5, 
	0xf5, 0xd5, 0x5f, 0x5f, 0xfd, 0xf5, 0xd7, 0xae, 
	0xfa, 0xfa, 0xaa, 0xaf, 0xbf, 0xfe, 0xfa, 0xe9, 
	0xff, 0xc6, 0xff, 0x3b, 0xff, 0xfc, 0xf3, 0xcf, 
	0x3f, 0xff, 0xfc, 0xf3, 0x9d, 0x7f, 0xfe, 0xf9, 
	0xe7, 0x9f, 0x7f, 0xfe, 0xf9, 0xbf, 0xb9, 0xff, 
	0x6c, 0xbd, 0xdf, 0xfe, 0xfb, 0xed, 0xbf, 0xff, 
	0x6e, 0xb6, 0xdf, 0x6f, 0xfb, 0xfd, 0xf7, 0xdf, 
	0x5f, 0xff, 0x6f, 0xee, 0xff, 0xeb, 0xaf, 0xbf, 
	0xfe, 0xfa, 0xeb, 0xaf, 0xbf, 0xff, 0xd5, 0x57, 
	0x5f, 0x7d, 0xf7, 0xf5, 0xd7, 0x5f, 0x7f, 0x9b, 
	0xff, 0xff, 0xfe, 0xfb, 0xef, 0xbf, 0xff, 0xfe, 
	0xfb, 0xef, 0x7f, 0xff, 0xdd, 0x77, 0xdf, 0x7d, 
	0xff, 0xfd, 0xf7, 0xff, 0xc6, 0xfe, 0xd7, 0x7f, 
	0xff, 0xfd, 0xf7, 0xdf, 0x7f, 0xff, 0xfd, 0xef, 
	0xbf, 0xbf, 0xbe, 0xfb, 0xef, 0xbf, 0xff, 0xfe, 
	0xb7, 0xf9, 0xff, 0xdf, 0x7f, 0xff, 0xfd, 0xf7, 
	0xdf, 0x7f, 0xff, 0xbd, 0x6f, 0xbf, 0xff, 0xfe, 
	0xbb, 0xef, 0xbf, 0xff, 0xfe, 0x6d, 0xf4, 0xff, 
	0xed, 0xb7, 0xdf, 0x7e, 0xfb, 0xed, 0xb7, 0xdf, 
	0xfe, 0xf6, 0xdb, 0x69, 0xbf, 0xfd, 0xf6, 0xdb, 
	0x6f, 0xff, 0x9b, 0xff, 0x7f, 0xff, 0xfd, 0xf7, 
	0xdf, 0x7f, 0xff, 0xfd, 0xf7, 0xbf, 0xff, 0xfe, 
	0xfb, 0xcf, 0xbb, 0xff, 0xfe, 0xfb, 0xff, 0xe6, 
	0xff, 0xdf, 0x7f, 0xff, 0xfd, 0xf7, 0xdf, 0x7f, 
	0xff, 0xfd, 0xee, 0xbf, 0xdf, 0xfe, 0xfb, 0xef, 
	0xbf, 0xef, 0xbe, 0xbf, 0xf9, 0xff, 0xfc, 0xf3, 
	0xcf, 0x3f, 0xff, 0xfc, 0xf3, 0xc7, 0x6f, 0xde, 
	0xb9, 0xf7, 0x9f, 0x7f, 0xfe, 0xf9, 0xe7, 0xff, 
	0x6f, 0xfe, 0xff, 0xfc, 0xf7, 0xcf, 0x7f, 0xff, 
	0xfc, 0xf7, 0xdf, 0x7f, 0xee, 0xf3, 0xe7, 0xbf, 
	0xff, 0xee, 0xfb, 0xef, 0xff, 0x9b, 0xdd, 0xcf, 
	0x3f, 0xff, 0xfc, 0xf3, 0xcf, 0x3f, 0xff, 0xfc, 
	0x67, 0x9f, 0x7f, 0xbe, 0xf9, 0xe7, 0x9b, 0x7f, 
	0xfe, 0xdd, 0x66, 0xff, 0xbd, 0xbf, 0xff, 0xff, 
	0xfb, 0xff, 0xbf, 0xff, 0xfe, 0xdf, 0xdf, 0xff, 
	0xfd, 0xfd, 0xf7, 0xdf, 0x7f, 0xff, 0xb7, 0xf9, 
	0xff, 0xfa, 0xfb, 0xef, 0xbf, 0xff, 0xfe, 0xfb, 
	0xef, 0x7f, 0xfd, 0xfd, 0xd7, 0xdf, 0x7f, 0xff, 
	0xfd, 0xf7, 0xf7, 0x6f, 0xfe, 0x9f, 0x5d, 0xf6, 
	0xda, 0x6f, 0xbf, 0xfd, 0xf6, 0xdb, 0xdf, 0x7e, 
	0xfb, 0xcf, 0xb7, 0xdf, 0x7e, 0xfb, 0xef, 0xff, 
	0x9b, 0xff, 0xff, 0xde, 0xff, 0xff, 0xff, 0xff, 
	0xff, 0xff, 0xff, 0xbb, 0xff, 0x7f, 0xfe, 0xff, 
	0xbf, 0xff, 0x7f, 0xfe, 0xbf, 0xe6, 0xff, 0xff, 
	0xff, 0xff, 0xff, 0xdf, 0xfd, 0xfe, 0xfd, 0xf7, 
	0xae, 0xff, 0xe9, 0xf3, 0xef, 0xff, 0xff, 0xfe, 
	0xff, 0xbf, 0xf9, 0xff, 0xf3, 0xff, 0xb7, 0xff, 
	0x7f, 0xfb, 0xff, 0xf7, 0xff, 0xf9, 0xbf, 0x8f, 
	0xff, 0xf7, 0xff, 0xff, 0xfb, 0xff, 0x67, 0x7e, 
	0xff, 0xbf, 0xef, 0xff, 0xff, 0xff, 0xff, 0xff, 
	0xff, 0xe7, 0xf7, 0x9f, 0xff, 0xff, 0x7f, 0xff, 
	0xff, 0xff, 0x7f, 0x9b, 0xff, 0x7e, 0xff, 0xf5, 
	0xf7, 0xdf, 0x7f, 0xff, 0xfd, 0xf7, 0xbe, 0xff, 
	0xfe, 0xfb, 0xee, 0xbb, 0xff, 0xfe, 0xfb, 0xff, 
	0xa6, 0xff, 0xff, 0xff, 0xff, 0xff, 0x7f, 0xbf, 
	0xff, 0xfe, 0xf7, 0xfd, 0x7f, 0xdb, 0xfa, 0xff, 
	0xff, 0x7e, 0xff, 0xff, 0xbf, 0xf9, 0xff, 0xff, 
	0xfd, 0x7f, 0xf7, 0xff, 0xff, 0xff, 0xfb, 0xef, 
	0x7f, 0xff, 0xf6, 0xff, 0xff, 0xff, 0xff, 0xff, 
	0xff, 0x6f, 0xfe, 0xff, 0xff, 0xdf, 0xff, 0xff, 
	0xff, 0xff, 0xff, 0xff, 0xbf, 0xff, 0xff, 0xfd, 
	0xff, 0xe7, 0xff, 0xff, 0xff, 0xff, 0x9b, 0xff, 
	0x7f, 0xff, 0xff, 0xff, 0xff, 0xff, 0xef, 0x7f, 
	0xff, 0x7f, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfb, 
	0xff, 0xff, 0xf7, 0xe6, 0xff, 0xff, 0xff, 0xfb, 
	0xff, 0xff, 0xff, 0xfb, 0xdf, 0x7f, 0x7f, 0xff, 
	0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xb9, 
	0xf9, 0xff, 0xff, 0xff, 0xaf, 0xff, 0xff, 0xfc, 
	0xff, 0xbf, 0xf7, 0xff, 0xfe, 0xf7, 0xff, 0xff, 
	0xfb, 0x6f, 0xdf, 0xff, 0x6b, 0xf8, 0xff, 0xff, 
	0xef, 0xdf, 0xff, 0xff, 0xff, 0xdf, 0xff, 0xff, 
	0xed, 0xff, 0xf7, 0xfc, 0xff, 0xff, 0xff, 0xbb, 
	0xff, 0x9b, 0xff, 0xbf, 0xff, 0xfe, 0xfe, 0xed, 
	0xff, 0xff, 0xff, 0xfe, 0xff, 0xff, 0xf7, 0xff, 
	0xf7, 0xff, 0xfb, 0xff, 0xff, 0xf7, 0xa6, 0xef, 
	0xf7, 0xfd, 0xfb, 0xff, 0xff, 0xff, 0xff, 0xff, 
	0xfb, 0xff, 0xff, 0xff, 0xff, 0xff, 0xdd, 0xd7, 
	0xef, 0xf7, 0xbf, 0xf9, 0xbb, 0xff, 0xdf, 0xff, 
	0xff, 0xfd, 0xff, 0xff, 0xff, 0xbb, 0xff, 0xff, 
	0xff, 0xfe, 0xfe, 0xfd, 0x9f, 0xff, 0xfb, 0x6f, 
	0xfa, 0xff, 0xff, 0xfc, 0xb3, 0xf7, 0x3f, 0xf2, 
	0xff, 0xf3, 0x9f, 0x7f, 0xfe, 0xfb, 0xc6, 0xff, 
	0xff, 0x7f, 0xff, 0xff, 0x9b, 0xff, 0xff, 0xbe, 
	0xf5, 0xdc, 0xff, 0xbf, 0xff, 0xff, 0xf6, 0xb7, 
	0x7f, 0xff, 0xf6, 0xef, 0xff, 0xff, 0xff, 0xff, 
	0xff, 0xe6, 0xff, 0x7f, 0x3f, 0xee, 0xfb, 0xa7, 
	0xff, 0xff, 0xff, 0x5d, 0xe7, 0xee, 0x79, 0xff, 
	0xfb, 0xfe, 0x9f, 0xff, 0xff, 0x8f, 0xf9, 0xef, 
	0xf7, 0xea, 0xf7, 0xff, 0xff, 0xff, 0xff, 0xff, 
	0x7f, 0xd9, 0xff, 0x5f, 0xef, 0xff, 0x5d, 0xf6, 
	0xff, 0xff, 0x6f, 0xfe, 0xff, 0xeb, 0xfe, 0xff, 
	0xff, 0xff, 0xff, 0xff, 0xff, 0xde, 0xff, 0xff, 
	0xf9, 0xff, 0x7d, 0x7f, 0xdd, 0xff, 0xff, 0x1b, 
	0xfe, 0xbf, 0xe7, 0xcb, 0x6f, 0xb9, 0xff, 0xfe, 
	0xfd, 0xef, 0x7f, 0x6b, 0xad, 0xff, 0xff, 0xf7, 
	0xff, 0xfb, 0xff, 0x3f, 0x66, 0xff, 0xfb, 0xff, 
	0xe6, 0x5f, 0xfe, 0xbf, 0xff, 0xff, 0xfb, 0x5f, 
	0xb6, 0xeb, 0xfb, 0xef, 0xfd, 0xff, 0xff, 0xff, 
	0xb7, 0xf9, 0xff, 0x7b, 0xdd, 0xff, 0xbe, 0xfb, 
	0xff, 0xff, 0xff, 0xff, 0xff, 0xa7, 0xff, 0xff, 
	0x4f, 0x3d, 0xff, 0xff, 0xff, 0x6f, 0xd6, 0xb7, 
	0xff, 0xf5, 0xf7, 0xef, 0xff, 0xff, 0xff, 0xff, 
	0xff, 0x7f, 0xfe, 0xff, 0xff, 0xfb, 0x4f, 0xff, 
	0xff, 0x5f, 0x9b, 0xfb, 0xbb, 0xd5, 0x65, 0xf7, 
	0x6f, 0xff, 0xfd, 0xff, 0xdf, 0xff, 0xfe, 0xf9, 
	0xff, 0x3d, 0xd1, 0xeb, 0xb3, 0xff, 0xef, 0x66, 
	0xfe, 0x7b, 0xf7, 0xff, 0xff, 0xdb, 0xff, 0xff, 
	0xff, 0xff, 0xff, 0x37, 0xed, 0xfe, 0xd1, 0xf4, 
	0xfb, 0xea, 0xff, 0xb3, 0xb1, 0xff, 0x5a, 0xfe, 
	0xff, 0xff, 0xfe, 0x7f, 0xff, 0xf5, 0xf7, 0xff, 
	0xdf, 0xbe, 0xdf, 0x7f, 0x6d, 0xbf, 0xff, 0xff, 
	0x66, 0xee, 0xff, 0xb7, 0xce, 0xff, 0xbf, 0xfd, 
	0x83, 0xff, 0x3f, 0xf1, 0x61, 0x2b, 0xff, 0x1f, 
	0x5f, 0xff, 0xff, 0xff, 0xbf, 0x9b, 0xf7, 0xff, 
	0xff, 0x6d, 0xb7, 0xfd, 0x7f, 0xff, 0xff, 0xf7, 
	0xbf, 0xff, 0xdf, 0xff, 0xff, 0xff, 0xff, 0xff, 
	0xff, 0xf7, 0xe6, 0xfd, 0xff, 0x7d, 0xf6, 0xd9, 
	0xff, 0x9f, 0xff, 0xff, 0xf9, 0xcf, 0x3f, 0xff, 
	0xef, 0xfb, 0x9f, 0xfc, 0xfb, 0xff, 0xbd, 0xb1, 
	0xff, 0xfb, 0xcc, 0x3e, 0xda, 0xfe, 0xf3, 0xef, 
	0x3f, 0xff, 0xf9, 0xd7, 0xda, 0x6c, 0xff, 0xfd, 
	0x77, 0xdf, 0xff, 0x66, 0xe6, 0xff, 0xef, 0xff, 
	0xfd, 0xfb, 0xff, 0xff, 0xff, 0xff, 0xff, 0xbf, 
	0xff, 0xff, 0xf9, 0xff, 0xfd, 0xf7, 0xfe, 0x3f, 
	0x9b, 0xfb, 0xff, 0xff, 0xef, 0xff, 0xff, 0xff, 
	0xfe, 0xff, 0xef, 0x7f, 0xf7, 0xff, 0xbf, 0xff, 
	0xff, 0xff, 0xf7, 0xff, 0xef, 0xa6, 0xfe, 0x7f, 
	0xb5, 0xdc, 0xf6, 0xfe, 0x1f, 0xff, 0xff, 0xf1, 
	0x87, 0xb7, 0xff, 0xfd, 0xf1, 0xf7, 0xf7, 0x7f, 
	0xbf, 0xab, 0x79, 0xff, 0xef, 0x9f, 0x7c, 0xf6, 
	0xfa, 0xef, 0xff, 0xff, 0xf6, 0xb1, 0xc7, 0xbe, 
	0xdf, 0xfc, 0x95, 0xdf, 0xb7, 0x7f, 0x63, 0xfe, 
	0xbf, 0xde, 0xb7, 0xff, 0xef, 0xff, 0xeb, 0xff, 
	0xbf, 0x7e, 0x75, 0xff, 0xfe, 0x9b, 0x5f, 0xff, 
	0xff, 0xf7, 0xfe, 0x9a, 0xff, 0xaf, 0xcf, 0x3f, 
	0xff, 0xec, 0xf3, 0xcf, 0x3f, 0xff, 0xdc, 0x67, 
	0x9f, 0x7b, 0xfc, 0xd1, 0xc7, 0x17, 0x7f, 0xbe, 
	0xe6, 0xff, 0xeb, 0xff, 0xff, 0xff, 0xfb, 0xdf, 
	0xff, 0xff, 0xfd, 0xe7, 0xff, 0xdf, 0x7e, 0xfd, 
	0xf5, 0xff, 0xff, 0xbf, 0xbf, 0xf9, 0xff, 0xfa, 
	0xff, 0xff, 0xbf, 0xff, 0xf7, 0xff, 0x7f, 0xff, 
	0xf9, 0xff, 0xbf, 0x5f, 0x7f, 0xfd, 0xfd, 0xfd, 
	0xbf, 0x6f, 0xfe, 0xff, 0xff, 0xff, 0xff, 0xbf, 
	0xff, 0xff, 0xff, 0xff, 0x6f, 0xff, 0xff, 0xff, 
	0xd7, 0x7f, 0xff, 0xdf, 0xff, 0xf7, 0x9b, 0xff, 
	0xff, 0xfd, 0xf7, 0xdf, 0x7b, 0xff, 0xfd, 0xff, 
	0xdf, 0xdb, 0xfe, 0xfb, 0xfb, 0xb5, 0xdf, 0xde, 
	0xfb, 0xbf, 0xff, 0xe6, 0xff, 0xdb, 0xef, 0xff, 
	0xff, 0xf6, 0xff, 0xff, 0xff, 0xbf, 0xfe, 0x17, 
	0xff, 0xdf, 0xff, 0xef, 0xa7, 0xf7, 0xff, 0xaf, 
	0xe9, 0xff, 0xa7, 0x3f, 0xfe, 0xfa, 0xeb, 0xaf, 
	0xbf, 0xfe, 0xaa, 0xd7, 0x5b, 0x7f, 0xfd, 0xf4, 
	0xd7, 0x5d, 0x7d, 0xfd, 0x6b, 0xfe, 0x3f, 0xfb, 
	0xf1, 0x8f, 0xcf, 0xfc, 0xf8, 0xff, 0x8f, 0x7e, 
	0xbc, 0xf3, 0x7f, 0x7f, 0xcf, 0xff, 0xff, 0xff, 
	0xff, 0x1b, 0xff, 0xff, 0x5b, 0xfe, 0xfe, 0xff, 
	0xbf, 0xef, 0xff, 0xfb, 0x5d, 0xdf, 0xfd, 0xbf, 
	0xff, 0xbf, 0xf7, 0xff, 0xef, 0x7f, 0xe6, 0xff, 
	0xff, 0xff, 0x7f, 0xff, 0xff, 0xfb, 0xff, 0xbd, 
	0xff, 0xfd, 0xfa, 0xfd, 0xaf, 0x7f, 0xfe, 0xff, 
	0xfe, 0xff, 0xaf, 0xf9, 0xff, 0x7b, 0xef, 0xaf, 
	0xe7, 0xfe, 0xbf, 0xff, 0xff, 0xf7, 0xff, 0xf7, 
	0xde, 0x7e, 0x7f, 0xbf, 0xf1, 0x47, 0xff, 0x6f, 
	0xfe, 0xff, 0xfb, 0xff, 0xdf, 0xff, 0xff, 0xff, 
	0xff, 0xff, 0xf6, 0xe7, 0xdf, 0x3d, 0xfd, 0xff, 
	0xfe, 0xfe, 0xfa, 0xff, 0x9b, 0xff, 0x6f, 0xbf, 
	0xff, 0xf8, 0xfb, 0xfe, 0xff, 0xff, 0xff, 0xff, 
	0x4f, 0xdf, 0xfd, 0x71, 0xdf, 0xff, 0xff, 0xef, 
	0xff, 0xe6, 0xff, 0xff, 0xff, 0xbf, 0xff, 0xff, 
	0x7f, 0x7f, 0xff, 0xe7, 0xff, 0xf5, 0xff, 0x77, 
	0xff, 0xd5, 0xff, 0xff, 0xff, 0xbf, 0xf9, 0xff, 
	0xff, 0xbf, 0xef, 0xfe, 0xff, 0xff, 0xff, 0xff, 
	0xff, 0xf7, 0xed, 0xbf, 0x6e, 0xfd, 0xfb, 0xbf, 
	0xff, 0xff, 0x6f, 0xfe, 0xff, 0xef, 0xe7, 0xff, 
	0xff, 0xff, 0xff, 0xff, 0xf3, 0x9f, 0xfd, 0xf7, 
	0xff, 0xff, 0xff, 0xff, 0xff, 0x91, 0xff, 0x9b, 
	0xff, 0xff, 0xff, 0xfb, 0xef, 0xff, 0xff, 0xff, 
	0xff, 0xfc, 0xe7, 0xf9, 0xff, 0xff, 0x9f, 0xff, 
	0xff, 0xff, 0xfd, 0xff, 0xe6, 0xff, 0xff, 0xa7, 
	0xdf, 0xfe, 0xff, 0xff, 0xff, 0xff, 0x3b, 0xbf, 
	0xff, 0x5d, 0xff, 0xfd, 0xd6, 0xd1, 0x7f, 0xff, 
	0xbf, 0xf1, 0xff, 0xff, 0xed, 0xdf, 0xff, 0xdb, 
	0xff, 0xff, 0xff, 0xfd, 0xff, 0xf5, 0xdb, 0x3d, 
	0x77, 0xfd, 0xff, 0xef, 0xff, 0x67, 0xfe, 0xff, 
	0x7f, 0xfb, 0xff, 0xff, 0xfb, 0xfb, 0xff, 0xff, 
	0xff, 0xff, 0xff, 0xfa, 0xdf, 0xdf, 0xfd, 0xff, 
	0xff, 0xff, 0x1b, 0xfe, 0xfc, 0xfe, 0xcb, 0x2b, 
	0xbb, 0xff, 0xff, 0xff, 0xef, 0x7f, 0xff, 0x4f, 
	0x3f, 0xbd, 0xff, 0xeb, 0xff, 0xff, 0x3f, 0x66, 
	0x3f, 0xff, 0xff, 0xb2, 0xcf, 0xfe, 0xff, 0xff, 
	0xff, 0xfb, 0xdf, 0xdf, 0xdf, 0x7f, 0xff, 0x3f, 
	0xfe, 0xff, 0xff, 0xb7, 0xf9, 0xff, 0x6f, 0xfd, 
	0xb9, 0xbe, 0xfb, 0xff, 0xff, 0xff, 0xff, 0xff, 
	0xff, 0xf7, 0xf2, 0x7e, 0xfd, 0xff, 0xbf, 0xff, 
	0x6f, 0xd6, 0xff, 0x9f, 0x3e, 0xfb, 0xef, 0xff, 
	0xff, 0xff, 0xff, 0xff, 0x4f, 0xff, 0xfd, 0x86, 
	0x59, 0xff, 0xff, 0xdb, 0x5f, 0x9b, 0xfb, 0xff, 
	0xbd, 0x56, 0x5b, 0x79, 0xff, 0xff, 0xff, 0xdf, 
	0xff, 0x5e, 0xfb, 0x7f, 0xa5, 0xff, 0xff, 0xff, 
	0xff, 0xef, 0x66, 0xfe, 0xff, 0xaf, 0x99, 0x77, 
	0xee, 0xff, 0xff, 0xff, 0xff, 0xff, 0xf7, 0xca, 
	0xbd, 0xef, 0xdf, 0xff, 0xff, 0xff, 0xb3, 0xb1, 
	0xff, 0x7f, 0xeb, 0xaf, 0xad, 0xff, 0xff, 0xff, 
	0xff, 0xfd, 0xff, 0xf5, 0xff, 0xd7, 0xff, 0xff, 
	0xff, 0xff, 0xff, 0x66, 0xe6, 0xff, 0x13, 0xdb, 
	0x7f, 0xef, 0xf4, 0xff, 0xff, 0x3f, 0xfc, 0xe1, 
	0xfd, 0xfd, 0xb7, 0xff, 0xff, 0xff, 0xff, 0xbf, 
	0x9b, 0xf5, 0x7f, 0xff, 0xff, 0xff, 0xdf, 0xfb, 
	0xff, 0xff, 0xf7, 0xbf, 0xff, 0xb7, 0xdf, 0x7e, 
	0xfb, 0xff, 0xb7, 0xdf, 0xf6, 0xe6, 0xfd, 0x9f, 
	0xff, 0xff, 0xff, 0xe7, 0xff, 0xff, 0xff, 0xf9, 
	0xcf, 0xff, 0xfb, 0xcf, 0xb3, 0xff, 0xff, 0xfb, 
	0xef, 0xbd, 0xb1, 0x5f, 0xf3, 0xef, 0xbf, 0xff, 
	0xfc, 0xfb, 0xef, 0x3f, 0xff, 0xf9, 0x76, 0xdf, 
	0x7f, 0x8d, 0xfd, 0xf7, 0xd9, 0xf7, 0x64, 0xe6, 
	0xdf, 0xff, 0xff, 0xfd, 0xff, 0xff, 0xff, 0xff, 
	0xff, 0xff, 0xb7, 0xff, 0xfe, 0xfb, 0xff, 0xbf, 
	0x7f, 0xff, 0x3f, 0x9b, 0xfb, 0xfd, 0xfe, 0xdf, 
	0xff, 0xbf, 0xff, 0xff, 0xff, 0xef, 0x7f, 0xf7, 
	0xef, 0x7f, 0xff, 0xff, 0xfd, 0xff, 0xff, 0xef, 
	0xa6, 0xfe, 0x4f, 0xed, 0xb5, 0xf7, 0xc7, 0xff, 
	0xff, 0xff, 0xf1, 0x8f, 0xd6, 0x7f, 0xff, 0xfb, 
	0xff, 0xde, 0x7f, 0xfc, 0xab, 0x79, 0xf7, 0xe6, 
	0xbb, 0xaf, 0xfe, 0xfb, 0xff, 0xff, 0xff, 0xfe, 
	0xf7, 0xdd, 0x9f, 0x7f, 0x7d, 0xbb, 0xef, 0xbb, 
	0x7f, 0x6f, 0xfe, 0xff, 0xfe, 0xfe, 0xfb, 0xff, 
	0xfe, 0xff, 0xff, 0xdf, 0xff, 0x7e, 0x9d, 0xff, 
	0xff, 0xef, 0xef, 0xff, 0xee, 0xff, 0x9b, 0xff, 
	0xef, 0x83, 0x3f, 0xfa, 0xfc, 0xf0, 0xcf, 0x3f, 
	0xbf, 0xfc, 0x65, 0x9f, 0x7d, 0xfe, 0xf1, 0xe7, 
	0x9f, 0x7f, 0xfe, 0xe6, 0xff, 0x8f, 0xb7, 0xff, 
	0xfe, 0xf7, 0xfd, 0x7f, 0xff, 0xf9, 0xcf, 0xff, 
	0x6f, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xbf, 
	0xf9, 0xff, 0xbe, 0xec, 0xff, 0xff, 0x2f, 0xff, 
	0xff, 0xff, 0xeb, 0x5f, 0xf7, 0xd9, 0xff, 0x7f, 
	0xff, 0xff, 0xff, 0xff, 0x6f, 0xfe, 0xff, 0x9e, 
	0xfb, 0xef, 0x7f, 0xe7, 0xff, 0xf7, 0xff, 0xeb, 
	0xdf, 0x7f, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 
	0xff, 0x9b, 0xff, 0xef, 0xf9, 0xf6, 0xdf, 0x7f, 
	0xfe, 0xff, 0xfd, 0x9f, 0xfb, 0xdc, 0xe3, 0xf9, 
	0xbd, 0xf7, 0xff, 0xfe, 0xff, 0xff, 0xe6, 0xff, 
	0xff, 0x6f, 0xbf, 0xfd, 0xfe, 0xff, 0xff, 0xef, 
	0xff, 0x9e, 0xf7, 0xbf, 0x7e, 0xfb, 0xff, 0xff, 
	0xff, 0xff, 0xbf, 0xe9, 0xff, 0xaf, 0xbe, 0x7c, 
	0xea, 0xeb, 0xaf, 0xbd, 0xfa, 0xfa, 0xd7, 0x5b, 
	0x7f, 0xd5, 0xf1, 0xd7, 0x5f, 0x7e, 0xfd, 0x6b, 
	0xfe, 0xfe, 0xfc, 0xe0, 0xb3, 0x5d, 0xef, 0xff, 
	0xf3, 0xef, 0x7e, 0xff, 0xff, 0xfe, 0x17, 0xfe, 
	0xff, 0xf7, 0xe7, 0xff, 0x1b, 0xff, 0xeb, 0x7c, 
	0xfe, 0xff, 0xfb, 0xfb, 0xfb, 0x6e, 0xb7, 0xff, 
	0xef, 0xff, 0xff, 0xfd, 0xff, 0xfd, 0x9f, 0xfe, 
	0x7f, 0xe6, 0xff, 0xef, 0xfb, 0xfe, 0xff, 0xff, 
	0xbe, 0xee, 0xfd, 0xfe, 0xf7, 0xfe, 0xfe, 0xff, 
	0xfe, 0xff, 0xff, 0x7e, 0xff, 0xaf, 0xf9, 0xff, 
	0xff, 0xef, 0xbf, 0xdf, 0xdf, 0xf7, 0xdf, 0xff, 
	0xff, 0xf3, 0x55, 0xfe, 0x9b, 0xff, 0xbf, 0xf5, 
	0xf6, 0xff, 0x6f, 0xf6, 0xf7, 0xff, 0xff, 0xff, 
	0xff, 0xff, 0xef, 0xef, 0xff, 0xff, 0xff, 0xdd, 
	0xff, 0xfd, 0xff, 0xdf, 0x5b, 0xaf, 0xff, 0x9b, 
	0xff, 0xbf, 0xbf, 0xfe, 0xf8, 0xef, 0xbf, 0xff, 
	0xfe, 0xff, 0xdf, 0x5f, 0xfd, 0xf8, 0xf7, 0xff, 
	0xdf, 0xff, 0xff, 0xff, 0xe6, 0xff, 0xbf, 0xff, 
	0xbb, 0xdf, 0xdf, 0x6b, 0xcf, 0xff, 0xff, 0xfb, 
	0xef, 0xfe, 0xf7, 0xff, 0xdf, 0xff, 0xdf, 0xff, 
	0xbf, 0xd9, 0xff, 0xf7, 0x1f, 0xef, 0xff, 0xf9, 
	0xf7, 0xef, 0xff, 0xbf, 0xaf, 0xff, 0xfd, 0xfe, 
	0xfe, 0xff, 0xdf, 0xf7, 0xee, 0x6e, 0xfe, 0xff, 
	0xff, 0xff, 0xff, 0xff, 0x3f, 0x7f, 0xff, 0xff, 
	0xdf, 0xff, 0xde, 0xf0, 0xfb, 0xff, 0xdf, 0xff, 
	0xff, 0xff, 0x9b, 0xfb, 0xff, 0xef, 0xff, 0xff, 
	0xff, 0xcf, 0xff, 0xff, 0xbf, 0xf7, 0xbf, 0xeb, 
	0xb3, 0xff, 0x7f, 0xff, 0xf9, 0xff, 0xff, 0xe6, 
	0xff, 0xdf, 0x3b, 0xff, 0xfc, 0xf7, 0xef, 0xff, 
	0xff, 0x7f, 0x77, 0xff, 0x5f, 0xff, 0x9f, 0xff, 
	0xf9, 0xff, 0xfe, 0xab, 0xe1, 0xff, 0xff, 0xaf, 
	0xd7, 0xdf, 0x7f, 0xfa, 0xff, 0xff, 0x7d, 0xed, 
	0xae, 0xdf, 0x7e, 0xff, 0xdf, 0xff, 0xd3, 0xff, 
	0x67, 0xfe, 0xff, 0xff, 0xba, 0xff, 0xfe, 0xbf, 
	0xff, 0xef, 0xff, 0xd7, 0xff, 0xff, 0xf7, 0xde, 
	0xfe, 0xff, 0xff, 0xff, 0xff, 0x1b, 0xfe, 0xbf, 
	0xfd, 0xf7, 0xdf, 0xbf, 0xff, 0xff, 0xff, 0xea, 
	0x97, 0xff, 0xe7, 0xf9, 0xfd, 0xdf, 0xff, 0xff, 
	0xff, 0x3f, 0x66, 0xff, 0xfb, 0xff, 0xff, 0xff, 
	0xff, 0xff, 0xff, 0xbf, 0xfb, 0xf5, 0xdf, 0xd9, 
	0xff, 0xef, 0xfd, 0xf7, 0xdf, 0xff, 0xb7, 0xf9, 
	0x5f, 0x7b, 0xfe, 0xa9, 0x97, 0xca, 0x77, 0xfe, 
	0xaf, 0x71, 0xfd, 0x3f, 0xde, 0xde, 0x2f, 0x3f, 
	0xff, 0xd4, 0xff, 0x6f, 0xd6, 0xbf, 0xdf, 0x3f, 
	0xeb, 0xad, 0xf3, 0xcf, 0xfe, 0xfb, 0xdd, 0xef, 
	0xff, 0xfd, 0xdf, 0x7b, 0xe7, 0x9f, 0xf7, 0x5f, 
	0x9b, 0xfb, 0xbf, 0xcb, 0xff, 0xdf, 0x6a, 0xff, 
	0x96, 0xff, 0xba, 0xbc, 0x65, 0xb7, 0xfd, 0x7c, 
	0xd9, 0x4c, 0x7b, 0xcd, 0xee, 0x66, 0xfe, 0xfb, 
	0xf7, 0xbe, 0xf7, 0xda, 0xbf, 0xf7, 0x97, 0xfb, 
	0xdd, 0x1f, 0xcb, 0x97, 0xf5, 0xbc, 0xda, 0x4c, 
	0xfb, 0xb3, 0xb1, 0xff, 0xfa, 0x6a, 0xaf, 0xf3, 
	0xff, 0xfd, 0xda, 0xaf, 0xff, 0xbb, 0xf7, 0xdf, 
	0x58, 0x5f, 0xbf, 0xfe, 0xd7, 0xff, 0x66, 0xee, 
	0xff, 0xff, 0xfa, 0x6f, 0xfd, 0xfd, 0xcf, 0xfe, 
	0x7b, 0xff, 0xcf, 0xf9, 0xef, 0xd7, 0x7f, 0xfb, 
	0xff, 0xf5, 0xbf, 0x9b, 0xf7, 0xff, 0xff, 0xff, 
	0xbf, 0xfc, 0xbf, 0xff, 0x6f, 0xbf, 0xbd, 0xf7, 
	0xb7, 0xdb, 0x7f, 0xfe, 0xed, 0xb7, 0x9f, 0xf7, 
	0xe6, 0xfd, 0xbf, 0xff, 0xf7, 0xdf, 0xff, 0xff, 
	0x79, 0xf7, 0x97, 0xdf, 0x3f, 0xfb, 0xbe, 0x3f, 
	0xff, 0xfe, 0xfe, 0xcb, 0xbd, 0xb1, 0xff, 0x7b, 
	0xed, 0xbb, 0xcf, 0x7e, 0x7b, 0xed, 0xbe, 0xdf, 
	0xf1, 0xd7, 0xd9, 0x7f, 0xbf, 0x7d, 0xf7, 0xdf, 
	0xff, 0x66, 0xe6, 0xdf, 0x7f, 0xff, 0xff, 0xf3, 
	0xdb, 0xff, 0xff, 0xbf, 0xf3, 0xff, 0xdf, 0xfe, 
	0xfb, 0xe7, 0xbf, 0xf7, 0xde, 0x3f, 0x9b, 0xfb, 
	0xfe, 0xef, 0xff, 0xff, 0xfe, 0xbb, 0xff, 0xff, 
	0xff, 0xfe, 0xff, 0xdf, 0xbf, 0xff, 0xfd, 0xfb, 
	0xf7, 0xff, 0xef, 0xa6, 0xfe, 0xff, 0xbf, 0xbf, 
	0xf7, 0xfe, 0xbf, 0xff, 0xbf, 0xf6, 0xdf, 0x3f, 
	0xef, 0xfd, 0xff, 0xfd, 0xfe, 0xdf, 0xff, 0xab, 
	0x79, 0xff, 0xaa, 0xbf, 0xef, 0xf6, 0xfa, 0xe7, 
	0xfb, 0xaf, 0x7e, 0xf3, 0xcf, 0xbf, 0xdf, 0xfe, 
	0xf5, 0xdf, 0x7e, 0x7f, 0x6f, 0xfe, 0xff, 0xdf, 
	0xbf, 0xeb, 0xed, 0xff, 0x5d, 0xfe, 0xff, 0xfd, 
	0x7e, 0xf9, 0xe5, 0xd3, 0x7b, 0x77, 0xff, 0xff, 
	0xff, 0x9b, 0xff, 0xaf, 0xcf, 0x1f, 0xfa, 0xec, 
	0xf3, 0x83, 0x3f, 0xbf, 0xf4, 0x47, 0x1f, 0x7d, 
	0xf4, 0xf1, 0x67, 0x1f, 0x7f, 0xfe, 0xe6, 0xff, 
	0xef, 0xf7, 0xdf, 0x7e, 0xfb, 0xdd, 0x74, 0xff, 
	0xff, 0xff, 0xff, 0xef, 0xff, 0xff, 0xfd, 0xf7, 
	0xdf, 0xff, 0xbf, 0xf9, 0xff, 0xfb, 0xfc, 0xbd, 
	0xbf, 0x3f, 0xff, 0xfa, 0xff, 0x6f, 0x7f, 0xff, 
	0xf9, 0xff, 0xff, 0xfd, 0xf7, 0xf7, 0xff, 0x6f, 
	0xfe, 0xdf, 0xbe, 0xff, 0xff, 0xbf, 0xef, 0xfd, 
	0xf7, 0xff, 0xea, 0xdf, 0x7f, 0xf5, 0xd7, 0x7f, 
	0xff, 0xff, 0xff, 0xff, 0x9b, 0xff, 0xbf, 0xfd, 
	0xd7, 0x5f, 0x7b, 0xff, 0xfd, 0xfd, 0xdf, 0xf7, 
	0xfe, 0x6b, 0xfb, 0xfd, 0xf7, 0xfe, 0xfb, 0xef, 
	0xff, 0xe6, 0xff, 0xfb, 0xff, 0xbf, 0xfd, 0xff, 
	0xdb, 0xef, 0xbf, 0xfd, 0xfc, 0x17, 0x97, 0x7e, 
	0xaa, 0xdf, 0x37, 0xff, 0xde, 0xbf, 0xe9, 0xff, 
	0x8f, 0xbf, 0xfe, 0xfa, 0xeb, 0xad, 0xb5, 0xfe, 
	0x6a, 0x97, 0x5f, 0x76, 0xf5, 0xb5, 0xd7, 0x5f, 
	0x7f, 0xfc, 0x6f, 0xfe, 0x7f, 0xfb, 0xff, 0x33, 
	0xfb, 0xbe, 0xec, 0xf3, 0x23, 0xff, 0xbd, 0xf6, 
	0xff, 0xef, 0xff, 0x7f, 0xf6, 0xdd, 0xef, 0x1b, 
	0xff, 0xff, 0xdf, 0xed, 0xff, 0xff, 0xbf, 0xbf, 
	0xde, 0xfb, 0xfd, 0xff, 0xbf, 0xcf, 0xde, 0xfd, 
	0xff, 0xff, 0xfb, 0xfd, 0xe6, 0xff, 0xff, 0xff, 
	0xfe, 0xf7, 0xff, 0xf9, 0xfe, 0xff, 0xaf, 0xef, 
	0xbf, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfa, 0xff, 
	0xbf, 0xf9, 0xdf, 0xfa, 0xeb, 0xbd, 0xbf, 0xdc, 
	0xff, 0xeb, 0xbf, 0xff, 0xcf, 0xf7, 0xf7, 0x5b, 
	0xbe, 0xbf, 0xf7, 0xd7, 0xf7, 0x67, 0xfe, 0xff, 
	0xfd, 0xbb, 0x7f, 0x9f, 0xfb, 0xff, 0xf6, 0xf6, 
	0xfe, 0xf7, 0xdf, 0xcf, 0xb5, 0xfd, 0xff, 0xff, 
	0xf7, 0xff, 0x99, 0xff, 0xef, 0xaf, 0xff, 0xfe, 
	0xe7, 0x9f, 0xff, 0xff, 0x7f, 0xfe, 0x5f, 0xff, 
	0xff, 0xf3, 0xdf, 0xdf, 0x7f, 0xdf, 0xff, 0xe6, 
	0xff, 0xff, 0xff, 0xff, 0xbd, 0xfe, 0x7b, 0xaf, 
	0xff, 0xfb, 0xef, 0xe7, 0xfe, 0x7f, 0xf7, 0x79, 
	0xff, 0xf7, 0xff, 0x9f, 0xf9, 0xff, 0x6f, 0xff, 
	0xff, 0x9f, 0x7f, 0x7e, 0xff, 0xff, 0x9f, 0xff, 
	0xb7, 0x7d, 0xde, 0x6f, 0xff, 0xff, 0x7f, 0xff, 
	0x6f, 0xfe, 0xff, 0x7f, 0xfc, 0xd7, 0xdf, 0x3b, 
	0xfa, 0xff, 0xf3, 0xbf, 0xeb, 0xf7, 0xf9, 0xff, 
	0xe7, 0xff, 0xff, 0xff, 0xff, 0x99, 0xff, 0xff, 
	0x3f, 0xdf, 0xfb, 0xf7, 0xbf, 0xff, 0xff, 0xd6, 
	0x5f, 0xef, 0x5f, 0x7d, 0xfe, 0xff, 0xef, 0xff, 
	0xff, 0xff, 0xe6, 0xff, 0xdf, 0xaf, 0xff, 0xfe, 
	0xf3, 0xef, 0xb7, 0xff, 0xdf, 0xf7, 0xfb, 0xf7, 
	0xef, 0xfd, 0xff, 0xff, 0xff, 0xfe, 0xbf, 0xf1, 
	0xff, 0xff, 0xef, 0xb7, 0x7e, 0xff, 0x5d, 0xef, 
	0xf7, 0xff, 0xb4, 0x9f, 0x9e, 0x5c, 0x5b, 0xfd, 
	0xff, 0xff, 0xff, 0x6f, 0xfe, 0xff, 0xfb, 0xfd, 
	0xf3, 0xff, 0xfe, 0xff, 0xfa, 0xff, 0xbf, 0xff, 
	0xff, 0xfb, 0xf7, 0xff, 0xff, 0xff, 0xdf, 0x7f, 
	0x1b, 0xfe, 0xff, 0xff, 0xff, 0x7e, 0x9e, 0xfc, 
	0xe7, 0x9c, 0xdf, 0x3f, 0xff, 0xac, 0xb7, 0xfc, 
	0xf7, 0xeb, 0x7c, 0xfd, 0x3f, 0x66, 0xff, 0xff, 
	0xff, 0xfd, 0xfe, 0x7f, 0xfd, 0xef, 0xe5, 0xff, 
	0xef, 0x7f, 0xeb, 0xcf, 0xfd, 0x77, 0xfe, 0xff, 
	0xff, 0xb7, 0xf9, 0x9f, 0xfa, 0xff, 0xf5, 0xe7, 
	0xcb, 0x57, 0xda, 0xff, 0xff, 0xfb, 0xff, 0x14, 
	0xf3, 0x4f, 0xfd, 0x5f, 0xfe, 0xff, 0x6f, 0xd6, 
	0xb7, 0xfe, 0x3d, 0xff, 0xff, 0xf3, 0x9d, 0xec, 
	0xff, 0xbf, 0xff, 0x3f, 0xf1, 0xfe, 0xfb, 0xff, 
	0xff, 0xff, 0x5f, 0x9b, 0xfb, 0xab, 0xfd, 0xff, 
	0xb6, 0xfd, 0xf5, 0x97, 0x5f, 0xdf, 0x3f, 0x7f, 
	0xff, 0x43, 0xec, 0xdd, 0xef, 0x7f, 0xcd, 0xee, 
	0x66, 0xfe, 0x6b, 0x7f, 0xff, 0x5a, 0xef, 0xbf, 
	0x67, 0xda, 0xff, 0xff, 0x5f, 0xdf, 0xbf, 0xfb, 
	0xfc, 0xfd, 0xff, 0xab, 0xb3, 0xb1, 0xff, 0xff, 
	0xff, 0xf5, 0x7f, 0xdf, 0x7d, 0xd8, 0xf5, 0xfe, 
	0xef, 0xf7, 0xd6, 0x77, 0xdf, 0xff, 0xff, 0xff, 
	0xff, 0x66, 0xee, 0xff, 0xff, 0xf7, 0xdf, 0xfd, 
	0xe7, 0xcf, 0x7e, 0x7f, 0xfc, 0xaf, 0x7d, 0x97, 
	0xfe, 0x5f, 0xff, 0xff, 0xff, 0xbf, 0x9b, 0xf7, 
	0xff, 0xff, 0x6f, 0xff, 0xee, 0xbb, 0xff, 0x2f, 
	0xf7, 0xbf, 0xf9, 0xff, 0x7b, 0x7f, 0xff, 0xfd, 
	0xff, 0xff, 0xf7, 0xe6, 0xfd, 0xff, 0x7f, 0xf7, 
	0xdd, 0xff, 0xff, 0x79, 0xf7, 0xf9, 0xef, 0xfc, 
	0xff, 0xec, 0xf3, 0xde, 0xfa, 0xff, 0xfb, 0xbd, 
	0xb1, 0xff, 0xfb, 0xed, 0x33, 0xdb, 0x76, 0x7b, 
	0xed, 0x3e, 0xde, 0xf9, 0xb7, 0x9f, 0x67, 0xad, 
	0x3d, 0xf6, 0xdb, 0xff, 0x66, 0xe6, 0xdf, 0x3f, 
	0xff, 0xfc, 0xf3, 0xdb, 0xff, 0xff, 0xff, 0xfb, 
	0xbf, 0xff, 0x7f, 0xfb, 0xff, 0xbf, 0xdf, 0xdf, 
	0x3f, 0x9b, 0xfb, 0xfb, 0xf7, 0xdf, 0xbf, 0xef, 
	0xbb, 0xff, 0xff, 0xff, 0xff, 0xf7, 0xff, 0xbf, 
	0xff, 0xff, 0xfd, 0xff, 0xff, 0xef, 0xa6, 0x7e, 
	0xfb, 0x2f, 0x96, 0xfb, 0xef, 0xbf, 0xef, 0xfe, 
	0xd1, 0xe7, 0xff, 0x7f, 0xb9, 0xb1, 0xf5, 0xff, 
	0x7b, 0xff, 0xab, 0x79, 0xff, 0xeb, 0xcb, 0xff, 
	0xff, 0xf9, 0xe7, 0xfb, 0xff, 0xfe, 0xfb, 0xee, 
	0x1e, 0xed, 0x6c, 0xd7, 0xee, 0x77, 0x7f, 0x6f, 
	0xfe, 0xbf, 0xff, 0xeb, 0xcf, 0xff, 0xde, 0xfd, 
	0xbf, 0xdf, 0xf7, 0xff, 0xff, 0xef, 0xfa, 0x5d, 
	0xf7, 0xff, 0x77, 0xff, 0x9b, 0xff, 0xbf, 0xcf, 
	0x3f, 0xfa, 0xfc, 0xf3, 0x8f, 0x3d, 0xff, 0xfc, 
	0xe3, 0x9f, 0x7f, 0x6e, 0xd8, 0xe7, 0x1f, 0x7f, 
	0xfe, 0xe6, 0xff, 0xfb, 0xbf, 0xbf, 0xf9, 0xf7, 
	0x9f, 0xff, 0xff, 0xff, 0xcf, 0x1a, 0xff, 0xff, 
	0x9f, 0xfe, 0xdf, 0x4f, 0xff, 0xbf, 0xf9, 0xff, 
	0xfb, 0xff, 0xaf, 0xff, 0xff, 0xff, 0xff, 0xff, 
	0xff, 0xff, 0xfd, 0xff, 0xff, 0xdf, 0xfd, 0xfd, 
	0xd7, 0xff, 0x6f, 0xfe, 0xbf, 0xff, 0xff, 0xef, 
	0x7f, 0xff, 0xff, 0xff, 0xff, 0xef, 0xff, 0xfd, 
	0xff, 0xff, 0xff, 0xff, 0xfd, 0xf5, 0xff, 0x9b, 
	0xff, 0xbf, 0xfd, 0xff, 0xf7, 0x7f, 0xff, 0xbd, 
	0xff, 0xdf, 0xbf, 0xdb, 0xfe, 0xef, 0x3f, 0xf6, 
	0xde, 0x6f, 0xed, 0xff, 0xe6, 0xff, 0xff, 0xff, 
	0xef, 0xff, 0xf7, 0xd3, 0xeb, 0xff, 0xff, 0xff, 
	0x97, 0x9f, 0x7a, 0xf1, 0xe5, 0x7f, 0xff, 0xfe, 
	0xbf, 0xe9, 0xff, 0xaf, 0xbf, 0xfa, 0xfa, 0xeb, 
	0xae, 0xb7, 0xfe, 0xf0, 0x13, 0x5f, 0x6f, 0xfd, 
	0xf5, 0x97, 0x5f, 0x7f, 0xfd, 0x6b, 0xfe, 0xff, 
	0xff, 0xff, 0xff, 0x2f, 0xff, 0xff, 0xf3, 0xff, 
	0xff, 0xfc, 0xfc, 0x7f, 0xef, 0xbf, 0xff, 0xff, 
	0xfd, 0xff, 0x1b, 0xff, 0xff, 0xef, 0x7f, 0xdf, 
	0xfb, 0xfa, 0x9b, 0xab, 0xf7, 0x75, 0x7f, 0xf7, 
	0xf3, 0xdf, 0xfd, 0xff, 0xdf, 0xbf, 0x7f, 0xe6, 
	0xff, 0xff, 0xff, 0xfe, 0xff, 0xfd, 0xbf, 0xbf, 
	0xce, 0xff, 0x6f, 0xff, 0xff, 0xff, 0xdf, 0xff, 
	0xff, 0xff, 0xff, 0xaf, 0xf9, 0xff, 0xef, 0xfb, 
	0xaf, 0xff, 0xde, 0x78, 0xe3, 0xff, 0x7f, 0xbd, 
	0xd5, 0xf7, 0xdf, 0xfe, 0xf9, 0x55, 0x5f, 0xff, 
	0x6f, 0xfe, 0xff, 0x77, 0xf7, 0xdb, 0xef, 0x5f, 
	0xbf, 0xbd, 0xbe, 0xbf, 0xfe, 0xba, 0xef, 0x5d, 
	0xdf, 0xf7, 0xfc, 0xfd, 0xff, 0x9b, 0xff, 0xff, 
	0xff, 0xef, 0xff, 0x8f, 0x7f, 0xfd, 0xff, 0xd7, 
	0xfb, 0xff, 0xff, 0xfb, 0xb3, 0xfe, 0x6f, 0xff, 
	0xfd, 0xff, 0xe6, 0xff, 0xff, 0xff, 0xfa, 0xfd, 
	0xfc, 0xff, 0xff, 0xdf, 0x7f, 0xbd, 0xbf, 0xdf, 
	0xff, 0xf7, 0xff, 0xff, 0xff, 0xff, 0xbf, 0xb9, 
	0xff, 0xff, 0xff, 0xfb, 0xff, 0xee, 0xff, 0xfd, 
	0xff, 0x7f, 0xff, 0xff, 0xf7, 0xfe, 0xef, 0xff, 
	0xaf, 0xbf, 0xff, 0x6e, 0xfe, 0x7f, 0x3f, 0xe8, 
	0xff, 0xff, 0x7f, 0xbf, 0xef, 0xfb, 0xbd, 0xff, 
	0xfa, 0xfb, 0x7d, 0x9f, 0x7f, 0xfe, 0xfb, 0xff, 
	0x9b, 0xfb, 0x7f, 0xff, 0xdd, 0xef, 0xbf, 0x7f, 
	0xfb, 0xff, 0x9e, 0x6f, 0xbf, 0xf7, 0xfe, 0xff, 
	0xb7, 0x7f, 0xfd, 0xfd, 0xef, 0xe6, 0xff, 0xff, 
	0x7f, 0xff, 0xbf, 0xfa, 0xef, 0xbf, 0xde, 0xfe, 
	0x37, 0xfd, 0xea, 0x77, 0xd9, 0xef, 0xaf, 0xff, 
	0xfe, 0xbf, 0xf1, 0xff, 0xff, 0x7f, 0xbf, 0xfe, 
	0x7e, 0xf9, 0xef, 0x1e, 0xff, 0xfd, 0xef, 0xff, 
	0x6b, 0xbb, 0xe3, 0xbe, 0xdf, 0xff, 0x67, 0xfe, 
	0xff, 0xff, 0xff, 0xef, 0xbf, 0xff, 0x7e, 0xfa, 
	0xed, 0x9f, 0xf7, 0xff, 0xff, 0xef, 0xff, 0xf7, 
	0xff, 0xd7, 0xfb, 0x1b, 0xfe, 0xff, 0xf0, 0xff, 
	0xef, 0xef, 0x39, 0xfc, 0xff, 0xcb, 0x7f, 0x7f, 
	0xfd, 0xf7, 0xfd, 0x57, 0xff, 0x7d, 0xf7, 0xbf, 
	0x66, 0xff, 0xdf, 0xe5, 0xd7, 0xf7, 0x7f, 0xf9, 
	0xff, 0xff, 0xfd, 0xef, 0xb7, 0x5f, 0x7d, 0xff, 
	0xf5, 0xbf, 0xdf, 0xfa, 0xb7, 0xf9, 0x9f, 0x5e, 
	0x5e, 0x65, 0xe6, 0xf7, 0xe3, 0xff, 0xbf, 0x7f, 
	0xff, 0xf7, 0xbf, 0xd3, 0x67, 0xf1, 0xe5, 0xf7, 
	0xf9, 0x6f, 0xd6, 0xe7, 0xde, 0x75, 0xf2, 0xf9, 
	0xbf, 0xff, 0xfd, 0xff, 0x7c, 0x7f, 0x9f, 0x61, 
	0xf6, 0x3f, 0x67, 0xf4, 0xfd, 0x5c, 0x99, 0xfb, 
	0x7f, 0xed, 0xf5, 0xc7, 0xef, 0x3f, 0xfe, 0xfd, 
	0xfa, 0xdf, 0x6b, 0xab, 0xab, 0xfc, 0x13, 0x4a, 
	0xfb, 0xfd, 0xef, 0x66, 0xfe, 0x9f, 0x66, 0xd6, 
	0xf9, 0xaf, 0xd9, 0x7f, 0xbf, 0xff, 0x7d, 0x73, 
	0x5f, 0x3b, 0x5f, 0xd4, 0xd3, 0x7e, 0xfd, 0x93, 
	0xb1, 0xff, 0x7e, 0xff, 0xef, 0xd7, 0xfe, 0xf9, 
	0xff, 0xaf, 0x7f, 0xfd, 0x97, 0xfa, 0x56, 0x2f, 
	0x2d, 0xef, 0xde, 0xff, 0x66, 0xee, 0xff, 0x12, 
	0x4f, 0x39, 0xb5, 0xbf, 0xcf, 0xff, 0x7b, 0x5f, 
	0x7b, 0xef, 0xb5, 0xff, 0x6a, 0xd9, 0x6f, 0xb7, 
	0xbf, 0x99, 0xf7, 0x7f, 0xdb, 0xfd, 0x37, 0xff, 
	0x7e, 0xff, 0xfd, 0xff, 0xff, 0xfd, 0xfe, 0xdf, 
	0x7f, 0xbf, 0xff, 0xf6, 0xdf, 0x76, 0xe6, 0xfd, 
	0xbf, 0xff, 0xff, 0xff, 0x7f, 0xfd, 0xfd, 0xe7, 
	0xfb, 0xdf, 0x3b, 0xff, 0xbc, 0xf7, 0xce, 0xbe, 
	0xeb, 0xcf, 0xbd, 0xb1, 0xff, 0xe3, 0xcf, 0x37, 
	0xff, 0x3e, 0xbb, 0xef, 0xb7, 0xff, 0xfd, 0xc7, 
	0x1f, 0x7f, 0xaf, 0xd9, 0x66, 0xdb, 0xab, 0x6e, 
	0xe6, 0xff, 0x7f, 0xbf, 0xff, 0xf7, 0xcf, 0xff, 
	0xff, 0xfc, 0xff, 0xff, 0xff, 0xfe, 0xfb, 0xef, 
	0xf7, 0xdf, 0xfe, 0x3f, 0x9b, 0xfb, 0xff, 0xef, 
	0xff, 0xff, 0xfe, 0xbe, 0xff, 0xbf, 0xff, 0xff, 
	0xff, 0xf7, 0xbf, 0xff, 0x7d, 0xff, 0xf7, 0xff, 
	0xed, 0xe6, 0xfe, 0x3f, 0xef, 0xdf, 0xfe, 0xfe, 
	0xdf, 0x3f, 0xff, 0xf6, 0xb5, 0xbf, 0x7e, 0xf8, 
	0xef, 0xd5, 0x7f, 0xff, 0xfb, 0xbb, 0x61, 0xdf, 
	0xe7, 0x8f, 0x7d, 0xfe, 0x7c, 0xe7, 0xcd, 0xbf, 
	0x7a, 0xd5, 0xcf, 0x37, 0x5f, 0x75, 0xf3, 0xc5, 
	0x5f, 0x7f, 0x6f, 0xee, 0xff, 0xda, 0xfe, 0xff, 
	0xfe, 0xdf, 0xff, 0x7a, 0xef, 0xdf, 0xe7, 0xff, 
	0xef, 0xdf, 0xff, 0xbe, 0xf7, 0xff, 0xff, 0x9b, 
	0xfb, 0xbe, 0xcf, 0x3e, 0xff, 0xfc, 0xf3, 0xcf, 
	0x2e, 0xfb, 0xf4, 0xe7, 0x9f, 0x7f, 0xfc, 0xf1, 
	0xe5, 0x9f, 0x7f, 0xfe, 0xe6, 0xff, 0xff, 0x7f, 
	0xff, 0xfd, 0xff, 0xdf, 0xbf, 0xff, 0xfe, 0xf7, 
	0x3f, 0xff, 0xff, 0xff, 0xe7, 0xff, 0xff, 0xff, 
	0xbf, 0xe1, 0xff, 0xff, 0xdf, 0xff, 0xff, 0xfe, 
	0xf7, 0xef, 0xeb, 0xff, 0xfd, 0xff, 0xff, 0x5f, 
	0x7f, 0x5f, 0xf5, 0xff, 0xff, 0x6f, 0xfe, 0xff, 
	0xfe, 0xff, 0xdf, 0xff, 0xff, 0xff, 0xbb, 0xef, 
	0xef, 0xff, 0xff, 0xff, 0xdf, 0x7f, 0x7e, 0xfd, 
	0xff, 0xff, 0x9b, 0xfb, 0xbf, 0xfd, 0xf5, 0xd7, 
	0xef, 0xff, 0xfd, 0xef, 0xde, 0xfb, 0xfe, 0xfb, 
	0xef, 0xbd, 0xf7, 0x5c, 0x7b, 0xef, 0xff, 0xe6, 
	0xff, 0xff, 0x6f, 0xbf, 0xfd, 0xf2, 0xbf, 0xff, 
	0xff, 0xfd, 0xff, 0x7f, 0xdf, 0x7e, 0xfb, 0xe7, 
	0xff, 0xdf, 0xfd, 0xb7, 0xf9, 0xff, 0xaf, 0x37, 
	0xfe, 0x7a, 0xeb, 0x2f, 0xbd, 0xf6, 0xf2, 0xd7, 
	0x5f, 0x7e, 0xdd, 0xf5, 0x97, 0x5f, 0x77, 0xfd, 
	0x6f, 0xee, 0xff, 0x6f, 0xf2, 0x83, 0xf5, 0xfb, 
	0xfc, 0xf3, 0xfb, 0xff, 0xed, 0xfb, 0xc1, 0x73, 
	0xfe, 0xfe, 0xab, 0xdf, 0xef, 0x1b, 0xff, 0xff, 
	0xf7, 0xb3, 0x6f, 0xff, 0x9b, 0x6f, 0xb6, 0x7f, 
	0xbf, 0xbf, 0xbf, 0xfe, 0xff, 0xf7, 0xb5, 0xe7, 
	0x7f, 0xdd, 0xe6, 0xff, 0x7f, 0xaf, 0xbf, 0xfe, 
	0xff, 0xff, 0xff, 0xff, 0xf7, 0xff, 0xfb, 0xaf, 
	0xea, 0xff, 0xff, 0xff, 0xff, 0xfe, 0xbf, 0xf9, 
	0xff, 0xff, 0xff, 0x2f, 0xfe, 0xdf, 0x58, 0xeb, 
	0xbf, 0xfe, 0xfd, 0xef, 0xd6, 0xfd, 0x7f, 0xfd, 
	0xfd, 0xd3, 0xff, 0x63, 0xfe, 0xff, 0x7f, 0xef, 
	0xef, 0xf3, 0xbd, 0xbf, 0x77, 0xfb, 0xf7, 0xdf, 
	0xff, 0xef, 0xfd, 0x7f, 0xff, 0xfd, 0xed, 0xff, 
	0x99, 0xff, 0xff, 0x7f, 0xde, 0xbe, 0x7f, 0xff, 
	0xbf, 0xef, 0xfb, 0x33, 0xff, 0x77, 0xff, 0xe7, 
	0xd6, 0xfe, 0xff, 0x7f, 0xff, 0xe6, 0xff, 0x7f, 
	0xaf, 0xbf, 0xfc, 0xef, 0xfd, 0xff, 0x37, 0xfe, 
	0xad, 0xff, 0xf7, 0xff, 0xff, 0xfd, 0xf7, 0xdf, 
	0xf5, 0x8f, 0xf9, 0xff, 0xdf, 0xfe, 0xfd, 0xff, 
	0xff, 0xdf, 0xff, 0xff, 0xff, 0xed, 0xff, 0x7f, 
	0xff, 0x3a, 0xfb, 0xb7, 0xf7, 0xf5, 0x6f, 0xfe, 
	0xff, 0xfb, 0xdf, 0xdf, 0xaf, 0x73, 0xeb, 0xff, 
	0xf3, 0xff, 0xf7, 0xf3, 0xf4, 0xe5, 0x1e, 0xfc, 
	0xf7, 0xff, 0xfe, 0x99, 0xff, 0xff, 0xff, 0xff, 
	0xff, 0xbf, 0xdf, 0xde, 0xef, 0xfa, 0xfe, 0xfb, 
	0xff, 0xf7, 0xf4, 0xdf, 0xff, 0xff, 0xff, 0xdf, 
	0xe6, 0xff, 0xbf, 0xbf, 0xff, 0xfe, 0xfb, 0xae, 
	0xbf, 0xdf, 0xfe, 0xe5, 0xdf, 0xeb, 0xdd, 0xff, 
	0xf5, 0xfe, 0xeb, 0xfe, 0xbf, 0xf1, 0xff, 0xdf, 
	0x6b, 0xb7, 0xbb, 0xfe, 0xff, 0xed, 0x9f, 0x7b, 
	0xfd, 0xfe, 0xff, 0xfe, 0xbe, 0xfd, 0x97, 0xd7, 
	0xff, 0x6f, 0xfe, 0xff, 0xff, 0xfe, 0xeb, 0xef, 
	0xbf, 0xef, 0xfa, 0xf7, 0xff, 0x7f, 0xff, 0xff, 
	0xff, 0x7f, 0xff, 0xfd, 0x7f, 0xfb, 0x1b, 0xfe, 
	0xef, 0xbf, 0xff, 0x0b, 0xbf, 0x7f, 0xfe, 0xf9, 
	0xef, 0xff, 0xf9, 0xfd, 0x97, 0xb5, 0x77, 0xca, 
	0x64, 0xf7, 0x3f, 0x66, 0xff, 0xfb, 0xef, 0xa7, 
	0x9f, 0xff, 0xbf, 0xff, 0xf2, 0xff, 0xff, 0xfc, 
	0xff, 0xe6, 0xed, 0xe5, 0xdf, 0xf3, 0xff, 0xb7, 
	0xf9, 0xff, 0xfe, 0xfb, 0xbf, 0xfc, 0x5b, 0xde, 
	0xff, 0xff, 0xe6, 0x3d, 0xdf, 0xd4, 0xf9, 0xcf, 
	0xfd, 0xdf, 0x5c, 0xff, 0x6f, 0xd6, 0xbf, 0xff, 
	0xfe, 0xfb, 0xdf, 0x73, 0xff, 0xff, 0xff, 0xdd, 
	0xe7, 0xbf, 0xf5, 0xe4, 0xf3, 0xe7, 0xbf, 0xf5, 
	0x5f, 0x9b, 0xfb, 0xef, 0xbf, 0x67, 0x97, 0xfd, 
	0xff, 0xff, 0xff, 0xda, 0xd6, 0xff, 0x5b, 0xed, 
	0xad, 0xdf, 0x4c, 0x97, 0xed, 0xef, 0x66, 0xfe, 
	0xbb, 0xef, 0xfd, 0xf9, 0xf7, 0x9b, 0xf5, 0xbf, 
	0xf2, 0x75, 0xfb, 0x4c, 0x7b, 0xe9, 0x3f, 0x53, 
	0xef, 0xb3, 0xb3, 0xb1, 0xff, 0xfe, 0xeb, 0xff, 
	0xf3, 0xff, 0xd6, 0x7f, 0x8c, 0xf5, 0x9d, 0xff, 
	0xff, 0x7f, 0x67, 0xff, 0xf7, 0xf5, 0xff, 0x66, 
	0xee, 0xbf, 0xff, 0x1f, 0x3f, 0xff, 0xbf, 0xff, 
	0x3f, 0x6b, 0xd1, 0x63, 0xef, 0xbf, 0xff, 0x58, 
	0x7b, 0xff, 0xb5, 0xbf, 0x9b, 0xf7, 0xff, 0xff, 
	0xff, 0xf7, 0xdf, 0xff, 0xf3, 0xef, 0xb7, 0xff, 
	0xff, 0xb7, 0xff, 0xff, 0xff, 0xf9, 0xe7, 0x9f, 
	0xf7, 0xe6, 0xdd, 0xff, 0xff, 0xff, 0xdf, 0x67, 
	0xfe, 0xfd, 0xd7, 0x59, 0xdf, 0xfe, 0xff, 0xff, 
	0x3f, 0xff, 0xfe, 0xf3, 0xcf, 0xad, 0xb1, 0xff, 
	0x7b, 0xed, 0x3f, 0xc7, 0x7a, 0xf3, 0xec, 0x36, 
	0xee, 0xdd, 0xf7, 0xdf, 0x6f, 0xaf, 0x7d, 0xf7, 
	0xdf, 0xff, 0x62, 0xe6, 0xff, 0x7f, 0xff, 0xff, 
	0xff, 0xdb, 0x6f, 0xff, 0xfc, 0xff, 0xff, 0xff, 
	0xfe, 0xf9, 0xef, 0xff, 0xff, 0xfe, 0x3f, 0x9b, 
	0xfb, 0xff, 0xf7, 0xff, 0xff, 0xff, 0xfd, 0xfb, 
	0xef, 0xfb, 0xff, 0xff, 0xdf, 0x7f, 0x7f, 0xff, 
	0xff, 0xef, 0xff, 0xef, 0xa6, 0xfe, 0xff, 0xaf, 
	0x9d, 0xfb, 0xd6, 0xff, 0xbf, 0xdf, 0xf1, 0xb7, 
	0xf7, 0xda, 0xfb, 0xe5, 0xb7, 0xdf, 0xdf, 0xfb, 
	0xab, 0x79, 0xff, 0x7f, 0xbf, 0x6f, 0xbe, 0xf8, 
	0xff, 0xdf, 0x7f, 0xfe, 0xd5, 0xdd, 0x5f, 0xdf, 
	0x7d, 0xf7, 0xe7, 0x7f, 0x7f, 0x6f, 0xfe, 0xff, 
	0xff, 0xba, 0xdf, 0xaf, 0xff, 0xdf, 0x7b, 0xbf, 
	0x5f, 0x6f, 0xfd, 0xfd, 0xf7, 0x7f, 0xff, 0x9f, 
	0x77, 0xff, 0x9b, 0xff, 0xff, 0xc7, 0x3f, 0xff, 
	0xe8, 0xf2, 0xcf, 0x3f, 0x3f, 0xd4, 0x45, 0x8f, 
	0x7d, 0xe6, 0xf1, 0xe7, 0x9f, 0x7f, 0xfe, 0xe6, 
	0xff, 0xff, 0xb5, 0xbf, 0xf9, 0xfa, 0xfd, 0x3f, 
	0xfe, 0x7d, 0xf7, 0xdf, 0xcf, 0x7f, 0xff, 0xf5, 
	0x9f, 0x7f, 0xff, 0xbf, 0xf9, 0xff, 0xff, 0xec, 
	0xef, 0xbf, 0x3e, 0xfe, 0xef, 0xff, 0xeb, 0x7d, 
	0xf7, 0xd9, 0x7f, 0xff, 0xff, 0xf7, 0xd7, 0xff, 
	0x6f, 0xfe, 0xff, 0xbf, 0xfb, 0xff, 0xaf, 0xab, 
	0xff, 0xff, 0xdf, 0xe9, 0xd7, 0x3f, 0xfd, 0xdf, 
	0xdf, 0x7f, 0xf9, 0xfd, 0xff, 0x9b, 0xff, 0xff, 
	0xfb, 0xf6, 0xd7, 0x6b, 0xac, 0xff, 0xfd, 0x9f, 
	0xfb, 0xfc, 0xe3, 0xed, 0xbd, 0xdf, 0x5e, 0x7e, 
	0xed, 0xff, 0xe6, 0xff, 0xd7, 0xef, 0xff, 0xff, 
	0xff, 0xdb, 0xff, 0xfd, 0xff, 0xff, 0xb7, 0xff, 
	0xff, 0xfb, 0xfd, 0xff, 0x7f, 0xfe, 0xbf, 0xe9, 
	0xff, 0xaf, 0xbb, 0xfe, 0xfa, 0xeb, 0xad, 0xbf, 
	0xfe, 0xfa, 0x97, 0x5f, 0x3f, 0xf5, 0x75, 0xd7, 
	0x5f, 0x7f, 0xf9, 0x6b, 0xfe, 0xfd, 0xff, 0xff, 
	0x3d, 0x3f, 0xba, 0xed, 0xf3, 0x8d, 0xff, 0x3d, 
	0xf6, 0xff, 0xf5, 0xfd, 0xbf, 0xd9, 0x7f, 0xff, 
	0x1b, 0xff, 0xff, 0xdb, 0xed, 0xef, 0xf7, 0xdb, 
	0x9f, 0xfd, 0xfa, 0xfe, 0xff, 0xff, 0xff, 0xff, 
	0xfb, 0xbb, 0xef, 0xff, 0x7f, 0xe6, 0xfe, 0x7f, 
	0xff, 0xff, 0xbf, 0xeb, 0xff, 0xdf, 0xfb, 0xff, 
	0x5f, 0xfd, 0xff, 0xfb, 0xef, 0xff, 0x5b, 0xfd, 
	0xfd, 0xbf, 0xf9, 0x7f, 0xff, 0xf3, 0xff, 0xbd, 
	0x8e, 0x5f, 0xff, 0x0f, 0xff, 0x7d, 0xf7, 0xfa, 
	0x7f, 0x6f, 0xe5, 0xf5, 0xd7, 0xfb, 0x6f, 0xfe, 
	0xff, 0x7f, 0xef, 0xff, 0xba, 0xdf, 0xff, 0xff, 
	0x77, 0xff, 0xff, 0xff, 0xff, 0xf7, 0x7f, 0x77, 
	0xfd, 0xed, 0x7d, 0x9b, 0xbf, 0xfd, 0xff, 0xff, 
	0x79, 0xfb, 0x7e, 0xed, 0xdf, 0xa9, 0xf7, 0x1f, 
	0xff, 0xed, 0x73, 0xf5, 0xfb, 0xcf, 0xff, 0xff, 
	0xe6, 0x7f, 0x7f, 0x7b, 0xbb, 0xff, 0x72, 0xfb, 
	0x2f, 0xff, 0xff, 0xef, 0xff, 0x9e, 0x7f, 0xfb, 
	0xff, 0x7f, 0xfd, 0xff, 0xb7, 0xb9, 0xff, 0xff, 
	0xff, 0xb5, 0xfb, 0xff, 0x5e, 0xff, 0xff, 0xae, 
	0xc7, 0xff, 0xdf, 0x7b, 0xff, 0xf7, 0xbf, 0xff, 
	0xff, 0x6b, 0xee, 0xff, 0xff, 0xfd, 0xdf, 0x7f, 
	0xfa, 0xef, 0xef, 0xf3, 0xfa, 0x7f, 0xfe, 0xf9, 
	0xd7, 0xfd, 0xfb, 0x76, 0xf1, 0xff, 0x9b, 0xfb, 
	0xff, 0xfd, 0xee, 0xff, 0xff, 0xff, 0xfe, 0xff, 
	0x7c, 0xfd, 0xfb, 0xee, 0xfd, 0xff, 0xfd, 0xaf, 
	0xff, 0xfd, 0xff, 0xe6, 0xff, 0xeb, 0xff, 0xbd, 
	0xfe, 0xbf, 0xff, 0xa6, 0xcb, 0xef, 0xff, 0x8f, 
	0xaf, 0xbe, 0x55, 0xff, 0x5f, 0x4f, 0xff, 0xbf, 
	0xf1, 0xef, 0xfb, 0xdd, 0xff, 0xdf, 0xff, 0xda, 
	0xef, 0xff, 0xf6, 0x7f, 0xd6, 0x7f, 0x3f, 0xbb, 
	0xfb, 0x2f, 0xdf, 0xff, 0x67, 0x7e, 0x5f, 0xff, 
	0xff, 0xff, 0xff, 0xff, 0xff, 0xfb, 0xff, 0xff, 
	0x3f, 0xfd, 0xff, 0x6f, 0xff, 0x7f, 0xf7, 0xf7, 
	0xff, 0x1b, 0xfe, 0xff, 0xd7, 0xca, 0x0f, 0xaf, 
	0xf9, 0xe7, 0xf9, 0x3a, 0x3f, 0x5f, 0x7f, 0xb5, 
	0x7c, 0x56, 0xeb, 0xe1, 0xf5, 0xbf, 0x66, 0xff, 
	0xff, 0xec, 0xe7, 0x5f, 0x6e, 0xed, 0xf9, 0xbd, 
	0xfe, 0x9f, 0xd7, 0x5f, 0x4e, 0x3d, 0xf5, 0xbf, 
	0x72, 0xff, 0xb7, 0xf9, 0xff, 0x3f, 0x3f, 0xaf, 
	0x96, 0xff, 0xfe, 0xbf, 0xaf, 0xff, 0x3b, 0xf5, 
	0xd2, 0xdf, 0xff, 0x35, 0xf7, 0x5f, 0xea, 0x6f, 
	0xd6, 0xff, 0xdf, 0xff, 0xeb, 0xbf, 0xb7, 0xfe, 
	0x3f, 0xeb, 0xbf, 0x4e, 0xfd, 0xfd, 0xd7, 0xdf, 
	0xe7, 0xfd, 0x7d, 0x5e, 0x99, 0xfb, 0xff, 0xef, 
	0xf6, 0xbf, 0x69, 0xe1, 0xbf, 0xfe, 0xdb, 0xbf, 
	0x5f, 0x33, 0xcd, 0x3e, 0xfb, 0x5e, 0xff, 0xbd, 
	0xee, 0x66, 0xfe, 0xff, 0xef, 0x96, 0x5f, 0x6f, 
	0xa9, 0xa7, 0xbe, 0x6a, 0xff, 0x57, 0x5f, 0x7d, 
	0xf7, 0x5e, 0x5b, 0x6f, 0xb4, 0x93, 0xb1, 0xff, 
	0x7f, 0x7d, 0xaf, 0xff, 0xfb, 0xfe, 0xea, 0xaf, 
	0xf2, 0xbf, 0xfc, 0x57, 0xfb, 0x8b, 0xb9, 0xf6, 
	0xdd, 0xff, 0x66, 0xee, 0xff, 0xff, 0x0f, 0x6f, 
	0xaf, 0xbd, 0xfe, 0x3a, 0xeb, 0xf5, 0x2f, 0xf5, 
	0xb5, 0x70, 0xde, 0xa8, 0xed, 0xed, 0xbf, 0x99, 
	0xf7, 0xff, 0xdb, 0xfd, 0xbf, 0xdd, 0xff, 0xfb, 
	0xcf, 0xb7, 0xff, 0xed, 0xfe, 0xdf, 0x6e, 0xbe, 
	0xff, 0xff, 0x9f, 0x77, 0xe6, 0xfd, 0xff, 0x7f, 
	0xf6, 0xdb, 0x67, 0xfe, 0xf1, 0xff, 0x19, 0xff, 
	0x3f, 0xf3, 0xef, 0xf3, 0xdf, 0xff, 0xf3, 0xec, 
	0xbd, 0xa1, 0x5f, 0x7b, 0xcd, 0xbb, 0xc7, 0x78, 
	0xdb, 0xef, 0x3f, 0xd6, 0xfd, 0xe7, 0xdb, 0x69, 
	0xba, 0xa9, 0xf6, 0x5b, 0xbd, 0x6e, 0xe6, 0xdf, 
	0x7f, 0xff, 0xfd, 0xf7, 0xdb, 0x7f, 0xff, 0xbd, 
	0xf7, 0xbf, 0xdf, 0xfe, 0xfb, 0xfd, 0xff, 0xdf, 
	0xfe, 0x3f, 0x9b, 0x7b, 0xfb, 0xf7, 0xbb, 0x7f, 
	0xff, 0xfd, 0xef, 0xef, 0xff, 0xfe, 0xfb, 0xed, 
	0xdf, 0xdf, 0x7f, 0xff, 0xdf, 0xff, 0xed, 0xe6, 
	0xfe, 0xeb, 0x6f, 0xbc, 0xf7, 0x46, 0xff, 0xaf, 
	0xff, 0xf9, 0xed, 0x97, 0x7f, 0x7b, 0xe1, 0xdc, 
	0xdf, 0xff, 0xf8, 0xbb, 0x61, 0xff, 0xf6, 0x8d, 
	0xad, 0xfa, 0xf8, 0xf7, 0xcb, 0x7f, 0xde, 0xf9, 
	0xc5, 0x5e, 0x5b, 0xbc, 0xf1, 0xcf, 0x3b, 0x7f, 
	0x6f, 0xfe, 0xbf, 0xde, 0xf7, 0xef, 0xbf, 0x9e, 
	0xfe, 0xba, 0xcf, 0xfd, 0x3f, 0xfd, 0xfd, 0xd2, 
	0xdb, 0xfd, 0xff, 0xe7, 0xff, 0x9b, 0xff, 0xaf, 
	0xcb, 0x3f, 0xff, 0xf8, 0xa0, 0xcf, 0x3e, 0xbf, 
	0xfc, 0x47, 0x07, 0x7f, 0xe4, 0xd9, 0xe7, 0x1f, 
	0x7f, 0xfe, 0xe6, 0xbf, 0x8b, 0x6f, 0xbe, 0xfe, 
	0xfe, 0xef, 0x2f, 0xfe, 0xf9, 0xcf, 0x97, 0x7f, 
	0x7c, 0xf9, 0xe7, 0xff, 0x7f, 0xff, 0xbf, 0xe1, 
	0x7f, 0xfa, 0xed, 0xaf, 0xff, 0x5e, 0xfa, 0xeb, 
	0xff, 0xff, 0xff, 0xe5, 0xdb, 0xdf, 0x7e, 0xff, 
	0xff, 0xff, 0xff, 0x6f, 0xfe, 0xbf, 0xae, 0xff, 
	0xff, 0xbf, 0xeb, 0xfe, 0xfa, 0xff, 0xea, 0xdf, 
	0x1d, 0xfd, 0xd7, 0x7f, 0xfe, 0xff, 0xf7, 0xff, 
	0x9b, 0xfb, 0x2f, 0xc3, 0xf7, 0xdf, 0x7b, 0x21, 
	0xbf, 0xfc, 0x9f, 0xba, 0x55, 0x03, 0xef, 0xb5, 
	0xf7, 0xfe, 0x7a, 0xed, 0xff, 0xe6, 0x7f, 0xff, 
	0xff, 0xb7, 0xbd, 0xf4, 0xfa, 0xff, 0x7f, 0xf5, 
	0xfe, 0xf7, 0x5f, 0x7c, 0xf9, 0xff, 0xa7, 0xde, 
	0xee, 0xbf, 0xf9, 0xff, 0xaf, 0xbf, 0xde, 0xa8, 
	0xcb, 0x8e, 0x9d, 0xfa, 0xba, 0x97, 0x4b, 0x2c, 
	0xb9, 0xf4, 0xd7, 0x5c, 0x7f, 0xfd, 0x6f, 0xfe, 
	0xfb, 0x7f, 0x7f, 0xfb, 0x3d, 0xfb, 0xd7, 0xef, 
	0xff, 0xf6, 0xbe, 0xf1, 0xbf, 0xff, 0x7f, 0xf7, 
	0xf7, 0xd9, 0x6d, 0x1b, 0xff, 0xfb, 0xff, 0xdf, 
	0xff, 0xbd, 0xff, 0xff, 0x79, 0x67, 0xaf, 0xdb, 
	0xbf, 0xff, 0x7f, 0xde, 0xfd, 0xbf, 0xff, 0xfc, 
	0xe6, 0xfd, 0x7f, 0xf7, 0xfb, 0xf1, 0xca, 0x7f, 
	0x7f, 0xf3, 0xff, 0x7f, 0xef, 0xfe, 0xfb, 0xff, 
	0xbf, 0xff, 0xfd, 0xff, 0xbf, 0xf9, 0x5f, 0xf6, 
	0xff, 0xab, 0xff, 0xdd, 0xea, 0xa3, 0xaf, 0xf7, 
	0xbd, 0xf4, 0xfe, 0xcf, 0x7f, 0xbe, 0xf5, 0xd7, 
	0x7a, 0x6e, 0xfe, 0xff, 0xbe, 0xff, 0xeb, 0xff, 
	0xef, 0xfe, 0xee, 0xde, 0xdf, 0x7f, 0xfb, 0xff, 
	0xdf, 0xf7, 0xff, 0xfb, 0xf7, 0xfd, 0x98, 0xff, 
	0x3f, 0xff, 0xdb, 0x3f, 0xfe, 0x0f, 0xd5, 0xef, 
	0xde, 0xdb, 0x3f, 0xfb, 0xef, 0xef, 0xff, 0xdf, 
	0x27, 0xef, 0xff, 0xe6, 0x7f, 0xff, 0x7f, 0xf7, 
	0xfd, 0xff, 0xeb, 0xef, 0xdf, 0xff, 0xee, 0xd7, 
	0xff, 0xe6, 0xf7, 0xef, 0xfe, 0xfb, 0xff, 0x9f, 
	0xf9, 0xff, 0xf7, 0x3e, 0xff, 0xfd, 0xdf, 0x9f, 
	0xf9, 0xfd, 0xfd, 0xbb, 0xff, 0xfe, 0xfe, 0xed, 
	0xff, 0xdf, 0xff, 0xff, 0x6f, 0xfe, 0x37, 0xfe, 
	0x3d, 0xff, 0x4f, 0xff, 0xdf, 0xbf, 0xbf, 0xf6, 
	0xfe, 0xfe, 0xff, 0xfb, 0xff, 0xff, 0xe7, 0xfa, 
	0x7f, 0x98, 0xff, 0xdf, 0xfe, 0xfd, 0xff, 0xf3, 
	0xfe, 0xff, 0xff, 0xff, 0xff, 0xaf, 0xdf, 0xff, 
	0xff, 0xfb, 0xf4, 0xff, 0xfe, 0xff, 0x66, 0xff, 
	0xfe, 0xbf, 0xfb, 0x7e, 0xdf, 0xcf, 0xbf, 0xd7, 
	0xfc, 0xb5, 0xd7, 0xff, 0xbf, 0xcd, 0xff, 0xd7, 
	0xfd, 0xff, 0xbf, 0xe1, 0x3f, 0xff, 0x6b, 0xbf, 
	0xed, 0xed, 0xf9, 0xe7, 0x9f, 0xfd, 0xfd, 0xff, 
	0xdd, 0x7f, 0xfe, 0xff, 0xff, 0xff, 0xff, 0x6b, 
	0xfe, 0xff, 0xfb, 0x5e, 0xf3, 0xff, 0xff, 0xf6, 
	0xdb, 0xb7, 0xbf, 0xff, 0xbf, 0x76, 0xd7, 0xef, 
	0xfb, 0xbf, 0xff, 0xff, 0x9a, 0xff, 0xe6, 0xfa, 
	0xaf, 0xbf, 0xbf, 0x7f, 0xff, 0xcb, 0xaf, 0xbe, 
	0xfc, 0xc8, 0xf7, 0xef, 0x3c, 0xf8, 0xcf, 0x8f, 
	0xef, 0x86, 0xff, 0xff, 0xef, 0xfe, 0xcb, 0xee, 
	0xfb, 0x3f, 0xff, 0xc7, 0xbf, 0xdf, 0xd3, 0xfc, 
	0xfb, 0xb5, 0x7c, 0xd9, 0xfd, 0xaf, 0xd9, 0xff, 
	0x5f, 0xda, 0x7c, 0xb3, 0xfb, 0x7f, 0xed, 0xf9, 
	0xf3, 0xff, 0xfd, 0x72, 0xea, 0xff, 0x9f, 0xff, 
	0xf7, 0xff, 0x6d, 0xfe, 0xff, 0xff, 0x5e, 0xfa, 
	0xef, 0xbf, 0xfe, 0x7a, 0x7e, 0xff, 0xcf, 0xfd, 
	0xfd, 0xff, 0x5f, 0x7f, 0xf3, 0xdd, 0xfc, 0x9b, 
	0xf7, 0xff, 0xbf, 0xdf, 0xfb, 0xfb, 0xbf, 0xb7, 
	0xde, 0xff, 0xff, 0xdb, 0x7f, 0xff, 0xff, 0xff, 
	0x99, 0x7f, 0xff, 0x57, 0xe6, 0xfe, 0x6b, 0xef, 
	0xed, 0xfd, 0xde, 0xeb, 0xfb, 0xaf, 0x77, 0xbf, 
	0xd8, 0xcc, 0xff, 0xff, 0xb5, 0x12, 0xde, 0xff, 
	0xbb, 0xb9, 0xff, 0xea, 0xbb, 0x7f, 0x9e, 0xfb, 
	0xab, 0xbd, 0xbf, 0xce, 0xf7, 0xd5, 0x77, 0xff, 
	0xff, 0xef, 0xa4, 0xf7, 0xff, 0x64, 0xee, 0xbf, 
	0xda, 0xee, 0xfb, 0xeb, 0xbe, 0xfe, 0x7e, 0xff, 
	0x7b, 0xfd, 0xad, 0xfd, 0xff, 0x59, 0xcb, 0x99, 
	0xfd, 0xa7, 0x99, 0xfb, 0xaf, 0x85, 0xf7, 0xfb, 
	0x7b, 0xbf, 0xbf, 0xbf, 0xef, 0xff, 0xdf, 0x5d, 
	0xff, 0xff, 0xfa, 0x76, 0x63, 0xfb, 0x0d, 0xe6, 
	0xfd, 0xdf, 0x76, 0xff, 0x6d, 0xf7, 0xff, 0xfe, 
	0xff, 0xfd, 0x6f, 0xbb, 0xff, 0xff, 0xdf, 0xfe, 
	0xff, 0xed, 0xe7, 0x9d, 0x79, 0xf7, 0xe7, 0x9f, 
	0xff, 0xe6, 0xf9, 0x7f, 0xfc, 0x7f, 0xfe, 0xb3, 
	0xcf, 0xfe, 0xfb, 0xef, 0xff, 0xdf, 0x3e, 0x73, 
	0x6d, 0xec, 0xff, 0xf8, 0xe3, 0x8f, 0x3f, 0xdc, 
	0x7e, 0xfb, 0xcd, 0x75, 0xd8, 0xc9, 0xf7, 0xd9, 
	0x7d, 0xff, 0xd5, 0xc7, 0xaa, 0x9b, 0xf9, 0xff, 
	0xff, 0xff, 0xff, 0xfd, 0xf6, 0xdb, 0x6f, 0xff, 
	0xff, 0xef, 0xff, 0xdf, 0xfe, 0xff, 0xff, 0xbf, 
	0xef, 0xce, 0xe6, 0xfe, 0xff, 0xff, 0xff, 0xef, 
	0xbf, 0xff, 0xfd, 0xf7, 0xfb, 0xff, 0x7e, 0xff, 
	0xef, 0xff, 0xff, 0xff, 0xfb, 0x6f, 0xbb, 0xa9, 
	0xff, 0xd2, 0x0f, 0xf5, 0xbc, 0xf1, 0xfa, 0xef, 
	0x2d, 0xf6, 0xf3, 0xcf, 0xd6, 0x5f, 0xff, 0xef, 
	0xef, 0x9f, 0xfe, 0x6e, 0xde, 0xbf, 0xf8, 0xe3, 
	0x9f, 0x37, 0xbe, 0xfa, 0xf3, 0x8b, 0xff, 0xfc, 
	0xf3, 0xe5, 0xb7, 0xff, 0x7d, 0xb1, 0xcd, 0xdf, 
	0x9b, 0xff, 0xf7, 0xf7, 0xfe, 0xfb, 0xfb, 0xaf, 
	0xff, 0xfe, 0xfa, 0xff, 0xff, 0x3d, 0xfd, 0xf5, 
	0xff, 0x6f, 0xff, 0xff, 0xff, 0xe6, 0xff, 0xff, 
	0x30, 0xcf, 0x3c, 0x33, 0xec, 0xb3, 0x8b, 0x2c, 
	0xed, 0xf9, 0x45, 0x1f, 0x5d, 0xfe, 0xf1, 0xe7, 
	0x9f, 0xbf, 0xf9, 0xff, 0xf2, 0x8f, 0xff, 0xff, 
	0xfd, 0xfa, 0xef, 0x3f, 0xff, 0xfb, 0xef, 0xd7, 
	0x5f, 0x7f, 0xfd, 0xf7, 0xdf, 0xff, 0x6f, 0xf8, 
	0xbf, 0x5c, 0xfb, 0xff, 0x7f, 0x97, 0xfe, 0xfe, 
	0xea, 0xff, 0xff, 0xfb, 0xf4, 0xd7, 0x57, 0x7f, 
	0xff, 0xfd, 0xff, 0x9b, 0xff, 0xff, 0xeb, 0xfe, 
	0xfb, 0xff, 0xaa, 0xff, 0xee, 0xb2, 0xba, 0xf7, 
	0xd7, 0xfd, 0x75, 0xd7, 0x7f, 0xff, 0xff, 0xff, 
	0xe6, 0xff, 0x7f, 0xb1, 0xfd, 0xf6, 0x5f, 0x68, 
	0x6f, 0xbf, 0xa6, 0x3f, 0xdd, 0x40, 0x7e, 0xd9, 
	0xb5, 0xf7, 0xfe, 0xfb, 0xbf, 0xf9, 0xbf, 0xff, 
	0xcb, 0xff, 0xff, 0xfd, 0xf7, 0xd3, 0xff, 0x3f, 
	0xf9, 0xed, 0xf7, 0xf7, 0x7b, 0xfb, 0xed, 0x2f, 
	0xff, 0x6d, 0xfa, 0xf7, 0xeb, 0xad, 0xbe, 0xf6, 
	0xea, 0xe3, 0xae, 0xbf, 0xbe, 0xf5, 0x53, 0x5d, 
	0x7b, 0xf5, 0xa1, 0x57, 0x5f, 0xff, 0x9b, 0xf9, 
	0x3e, 0xff, 0xaf, 0xef, 0x6a, 0xef, 0xff, 0xff, 
	0xe7, 0x9f, 0x9f, 0xfd, 0xd9, 0xdf, 0x67, 0x9f, 
	0xee, 0xd1, 0xfb, 0xc6, 0xff, 0x7b, 0xf2, 0xfa, 
	0xff, 0xdb, 0xff, 0xff, 0xae, 0xeb, 0xed, 0xfd, 
	0x3f, 0xdf, 0xf7, 0x7e, 0xb5, 0xdf, 0x5d, 0xbf, 
	0x79, 0xff, 0xfd, 0x7f, 0xff, 0xfc, 0xff, 0xdf, 
	0xfe, 0xf6, 0xd3, 0xbe, 0xfe, 0xfb, 0xfe, 0xff, 
	0xff, 0xff, 0xef, 0xfe, 0x6f, 0xda, 0xf7, 0xff, 
	0xff, 0xff, 0xa5, 0xe7, 0x5b, 0xb8, 0xaf, 0x9f, 
	0x7f, 0xbe, 0xf5, 0xd6, 0x7f, 0x6f, 0x5f, 0xff, 
	0x7e, 0x19, 0xff, 0xff, 0xff, 0xdf, 0xbf, 0xdb, 
	0xff, 0x7f, 0xbf, 0x6e, 0xff, 0xf7, 0x5f, 0xdb, 
	0x6d, 0xff, 0xf7, 0xde, 0x7f, 0x7f, 0xa6, 0xfe, 
	0x7f, 0xff, 0xfd, 0xff, 0xfb, 0x6f, 0xbf, 0xff, 
	0xee, 0x77, 0x5e, 0x7e, 0xdf, 0xbd, 0xfd, 0xcf, 
	0x3f, 0xfb, 0xbf, 0xf1, 0xeb, 0xfe, 0xff, 0xef, 
	0x2f, 0xff, 0xff, 0xff, 0xff, 0xdb, 0xfb, 0xef, 
	0xe5, 0xf7, 0xf3, 0xff, 0xbd, 0xd7, 0xff, 0x65, 
	0xfe, 0xf7, 0xba, 0xff, 0xbb, 0xef, 0xf5, 0xf5, 
	0x97, 0x9f, 0xff, 0xe6, 0xb3, 0xb7, 0xbf, 0xfe, 
	0x7f, 0xbf, 0xfe, 0xff, 0x9b, 0xfd, 0xff, 0xbb, 
	0xde, 0xbc, 0xfd, 0xcf, 0x1f, 0x56, 0x7d, 0x65, 
	0xaf, 0xfb, 0x7b, 0xff, 0xed, 0xa9, 0x7f, 0xfe, 
	0x7f, 0xe6, 0xff, 0xfe, 0xfd, 0xbb, 0xf2, 0xbf, 
	0xed, 0xdf, 0xff, 0xfe, 0xef, 0x5f, 0xe7, 0xfb, 
	0xdf, 0xfb, 0xdf, 0xdf, 0xfe, 0xbb, 0xf9, 0xbf, 
	0xd7, 0x3f, 0xaf, 0xf3, 0xfe, 0xad, 0xff, 0xff, 
	0xfd, 0x9e, 0x7f, 0xbf, 0xef, 0x1e, 0xd9, 0xf6, 
	0x97, 0xff, 0x6e, 0xfe, 0xff, 0xff, 0xff, 0xfd, 
	0x9f, 0xfb, 0xf7, 0xf7, 0x7f, 0xfb, 0xfb, 0xff, 
	0x5f, 0xff, 0x7f, 0xff, 0xfa, 0xfe, 0xff, 0x9b, 
	0xff, 0xff, 0xff, 0xef, 0xff, 0xf7, 0xff, 0xfe, 
	0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xdf, 0xef, 
	0xff, 0xeb, 0xff, 0xcf, 0x86, 0xff, 0x6f, 0xff, 
	0xfe, 0xff, 0x67, 0xfd, 0xff, 0xfc, 0xcb, 0x5f, 
	0x7e, 0x53, 0x7f, 0xf7, 0xbf, 0x72, 0xff, 0xfd, 
	0x8f, 0xd9, 0xff, 0x7f, 0x5d, 0xbf, 0xff, 0x5b, 
	0xfa, 0x6b, 0x2f, 0x73, 0xbd, 0xe4, 0xd2, 0xd3, 
	0x7d, 0xfd, 0xbd, 0xfc, 0xff, 0x6d, 0xfe, 0xff, 
	0xfe, 0xff, 0x7f, 0xec, 0xb7, 0xde, 0x6a, 0xeb, 
	0x5d, 0x6d, 0x2d, 0x75, 0x9e, 0xff, 0x7f, 0xf3, 
	0xcf, 0xff, 0x9b, 0xf5, 0xff, 0xbf, 0xfe, 0x7f, 
	0xeb, 0xf5, 0xd7, 0x5f, 0x7f, 0xfd, 0xeb, 0x4f, 
	0xfd, 0xe7, 0xd7, 0xd3, 0xfd, 0xff, 0xd7, 0xe6, 
	0xfe, 0x6b, 0xf6, 0xd9, 0x25, 0xbf, 0x69, 0xaf, 
	0x9d, 0xf6, 0xb5, 0xd2, 0x4a, 0x33, 0xff, 0x3f, 
	0xf3, 0x4c, 0xf8, 0xbb, 0x99, 0xff, 0xde, 0xbf, 
	0xff, 0xfe, 0x7b, 0xef, 0xbd, 0xf1, 0xfe, 0xf7, 
	0xdf, 0x77, 0xdf, 0x7f, 0xad, 0xcc, 0xd3, 0xff, 
	0x6c, 0xec, 0xbf, 0xf6, 0xdf, 0xdf, 0xaf, 0xed, 
	0x8b, 0x7f, 0xbf, 0xff, 0xfb, 0xf7, 0xf5, 0xf7, 
	0xff, 0x2b, 0x2d, 0xf4, 0xbf, 0x99, 0xfb, 0xef, 
	0xff, 0x53, 0xe7, 0xeb, 0xaf, 0xb5, 0x92, 0x5a, 
	0x55, 0x5e, 0x7b, 0xf5, 0xbd, 0xd7, 0xbe, 0x7d, 
	0x85, 0xef, 0xe6, 0xfd, 0xff, 0x7f, 0xdb, 0x6f, 
	0x3f, 0xdf, 0x6a, 0xab, 0xed, 0x6d, 0xb7, 0xfd, 
	0xfe, 0xef, 0x3f, 0xfe, 0xfd, 0xfa, 0xbd, 0x79, 
	0xff, 0x7f, 0x9f, 0xf9, 0xe6, 0x9f, 0x27, 0x9f, 
	0x7c, 0xf2, 0x93, 0x4f, 0x3e, 0xff, 0xfd, 0x3f, 
	0xff, 0xba, 0x7f, 0x6f, 0xec, 0xff, 0xbe, 0xd3, 
	0xaf, 0xbf, 0x95, 0x58, 0xf2, 0x89, 0x57, 0x7e, 
	0xf1, 0xe5, 0xdb, 0x6f, 0xff, 0xdd, 0xe7, 0x3f, 
	0x99, 0xf9, 0xff, 0xdf, 0x7f, 0xff, 0xfd, 0x67, 
	0x9f, 0xed, 0xb6, 0xb5, 0xcf, 0x7e, 0xdf, 0x3f, 
	0xff, 0xee, 0xfb, 0xff, 0xcf, 0xe6, 0xfe, 0xff, 
	0xfd, 0xfa, 0xdf, 0xff, 0xda, 0x6b, 0xbe, 0xbd, 
	0xcd, 0xb5, 0xff, 0xfd, 0xff, 0x7f, 0xff, 0xff, 
	0xff, 0xbb, 0xa9, 0xff, 0x7a, 0x19, 0xaf, 0xfe, 
	0xfe, 0xc2, 0x0b, 0x2f, 0x7c, 0xe1, 0x85, 0x3f, 
	0xff, 0xfb, 0xed, 0x9d, 0x7a, 0xff, 0x6a, 0xde, 
	0xb7, 0xfa, 0x63, 0x89, 0x3f, 0xf7, 0x79, 0x67, 
	0x9d, 0xff, 0xec, 0xf3, 0xce, 0x57, 0xdd, 0x6d, 
	0xf5, 0xcf, 0xdf, 0x9b, 0xff, 0xff, 0xf7, 0xfb, 
	0xb2, 0xef, 0x7f, 0xf7, 0xfb, 0x6f, 0x7f, 0xff, 
	0xff, 0xff, 0x7f, 0xf7, 0x5d, 0xfe, 0xfb, 0xff, 
	0xe6, 0xff, 0xff, 0xf1, 0x87, 0x3e, 0xbb, 0xe8, 
	0xa2, 0x8f, 0x3e, 0xf5, 0x90, 0xe1, 0x1e, 0x7d, 
	0xf6, 0xd1, 0xe3, 0x8f, 0xbf, 0xf9, 0xff, 0xfb, 
	0xed, 0xa7, 0xff, 0x7e, 0xff, 0xdf, 0x7f, 0xff, 
	0xbb, 0xee, 0x13, 0xff, 0xff, 0xfd, 0xc7, 0x9a, 
	0xef, 0x6f, 0xfe, 0x9f, 0x3f, 0xfe, 0xeb, 0xff, 
	0x8f, 0xbe, 0xf2, 0xeb, 0x5b, 0x5e, 0x5d, 0xf4, 
	0xd7, 0xff, 0xff, 0xff, 0xf7, 0xff, 0x9b, 0xff, 
	0xbf, 0xe7, 0xde, 0xfb, 0xef, 0xaa, 0xbb, 0xfe, 
	0xf2, 0xd2, 0x57, 0x4e, 0xfd, 0xff, 0xf7, 0xff, 
	0xff, 0xb9, 0xff, 0xe6, 0xff, 0x7b, 0xec, 0xbd, 
	0xf6, 0x3b, 0x7f, 0xff, 0xfd, 0xe7, 0x3f, 0xff, 
	0x58, 0x7b, 0xed, 0xb5, 0xff, 0x7a, 0xea, 0xbf, 
	0xd9, 0xff, 0xf6, 0xfb, 0xef, 0xbf, 0xff, 0xf6, 
	0xdf, 0x6f, 0x75, 0xf9, 0xa9, 0x97, 0xfe, 0x7e, 
	0x6b, 0xfd, 0xff, 0xff, 0x6f, 0xea, 0x7f, 0x6b, 
	0xad, 0xbf, 0xde, 0xba, 0xab, 0x2f, 0xb7, 0xbe, 
	0x75, 0xd7, 0x5b, 0x7f, 0xad, 0x71, 0x57, 0x1f, 
	0xff, 0x9a, 0xff, 0xee, 0xfb, 0x7f, 0xad, 0xcf, 
	0xef, 0xbf, 0xff, 0xf2, 0xfd, 0x7b, 0xfe, 0xff, 
	0x65, 0x77, 0xeb, 0xf0, 0xfd, 0xfe, 0xc6, 0xff, 
	0xff, 0xff, 0xf7, 0xad, 0xbe, 0xff, 0xfe, 0xdb, 
	0xff, 0x3f, 0x5d, 0xff, 0x7e, 0xef, 0xbf, 0xf7, 
	0xfe, 0xef, 0x9f, 0xf9, 0xdf, 0xdf, 0xfc, 0xff, 
	0xff, 0xb6, 0x7f, 0xfd, 0xaf, 0xff, 0xff, 0xec, 
	0x3a, 0xbf, 0xfd, 0xf7, 0xff, 0xdb, 0xee, 0x6d, 
	0xfe, 0xef, 0xcf, 0x7e, 0xee, 0x6d, 0xbf, 0xfc, 
	0x60, 0xc9, 0x7f, 0x7b, 0xfd, 0xf5, 0xfe, 0x0e, 
	0xf5, 0xfd, 0xfd, 0xfe, 0x9b, 0xfd, 0xff, 0xff, 
	0xba, 0xff, 0xef, 0x6b, 0x6f, 0xf7, 0xdb, 0xff, 
	0xf7, 0xfe, 0xed, 0xff, 0xef, 0xef, 0xdf, 0x53, 
	0xdf, 0xe6, 0xff, 0xdf, 0x3f, 0x9d, 0xaf, 0xd7, 
	0x87, 0xbf, 0x3b, 0xfc, 0xf1, 0xb6, 0xdf, 0xff, 
	0x7f, 0xb7, 0xf7, 0xff, 0xff, 0xbf, 0xf9, 0xff, 
	0xee, 0xff, 0x7f, 0xf3, 0xff, 0xfa, 0xe3, 0xab, 
	0x7f, 0xff, 0xfd, 0xff, 0xff, 0x7e, 0xf6, 0xed, 
	0xd7, 0xff, 0x6d, 0xf6, 0xbf, 0x7f, 0xd7, 0x7f, 
	0xf7, 0xfb, 0xdf, 0xff, 0xff, 0xcf, 0xef, 0x6d, 
	0xdf, 0xff, 0x7f, 0xbd, 0x9d, 0xfe, 0xff, 0x9b, 
	0x7f, 0x7d, 0xff, 0x7f, 0xbf, 0xb3, 0xfd, 0xfb, 
	0xef, 0xff, 0x7e, 0xbc, 0xb7, 0xfe, 0x6f, 0xd7, 
	0xff, 0xf7, 0xff, 0xff, 0xa6, 0xff, 0xff, 0xff, 
	0xfa, 0xff, 0xf6, 0xbf, 0xff, 0xff, 0x3f, 0xbf, 
	0xbb, 0x7f, 0xdf, 0xff, 0xff, 0xff, 0xff, 0xff, 
	0xbb, 0xf9, 0xef, 0x67, 0xcf, 0xbd, 0xff, 0x1e, 
	0x7b, 0x6d, 0xb5, 0xfa, 0x9f, 0xef, 0xff, 0x5f, 
	0xbe, 0xeb, 0xff, 0xdf, 0xf7, 0x6e, 0xf8, 0xff, 
	0xfe, 0xfd, 0xe7, 0xd7, 0xfd, 0xfe, 0xf8, 0xef, 
	0xff, 0xff, 0xed, 0xbf, 0xff, 0xff, 0xde, 0xef, 
	0xf1, 0xbf, 0x99, 0xfe, 0xbf, 0xff, 0xff, 0xfb, 
	0xff, 0xcf, 0xff, 0xff, 0xfc, 0xfd, 0xbb, 0xff, 
	0xf7, 0xde, 0xff, 0xff, 0xff, 0xff, 0xff, 0xe6, 
	0xfd, 0xab, 0xef, 0xbc, 0xc2, 0xc7, 0xef, 0xf5, 
	0xfc, 0xf6, 0xf7, 0xbf, 0x79, 0xfd, 0x97, 0xbd, 
	0xd7, 0xdf, 0xff, 0xaf, 0xf9, 0xff, 0xef, 0xbb, 
	0xff, 0xfe, 0xfd, 0x3e, 0xbf, 0xef, 0x7f, 0xff, 
	0xbf, 0x72, 0xff, 0xfd, 0xfd, 0x75, 0xfe, 0xff, 
	0x6d, 0xee, 0xff, 0xff, 0xfe, 0xeb, 0x7f, 0xfd, 
	0xfe, 0x7a, 0xee, 0xff, 0xff, 0xfd, 0xf7, 0xd7, 
	0xff, 0x2e, 0xf9, 0xe7, 0xfa, 0x1b, 0xf5, 0xa9, 
	0xbf, 0xff, 0xff, 0xd7, 0xef, 0xbf, 0xde, 0xfe, 
	0xff, 0x53, 0x7f, 0x9f, 0xf5, 0x9e, 0x13, 0x67, 
	0x38, 0x57, 0x66, 0xfe, 0x7f, 0xa7, 0xbf, 0x66, 
	0xff, 0x7b, 0xa5, 0xed, 0x67, 0x37, 0xfb, 0x6b, 
	0xb3, 0x6f, 0x7f, 0x7b, 0x4a, 0xb3, 0x9b, 0xb9, 
	0xff, 0x5a, 0xfc, 0xf5, 0xfd, 0xff, 0xde, 0xa9, 
	0xff, 0x7d, 0xaf, 0xde, 0x73, 0xef, 0xfd, 0xf5, 
	0xf6, 0xb7, 0xed, 0x6c, 0xee, 0xbf, 0xfe, 0xda, 
	0xeb, 0x7f, 0xb7, 0xb7, 0x7f, 0xeb, 0x5f, 0x7f, 
	0x7d, 0xd7, 0xd5, 0xeb, 0x8f, 0x9f, 0xed, 0xbf, 
	0x19, 0xfb, 0xff, 0xfd, 0xf7, 0xdf, 0xdf, 0xeb, 
	0xff, 0x83, 0xfa, 0xd7, 0x5f, 0x2f, 0xef, 0x95, 
	0x8e, 0xff, 0x7d, 0xf3, 0xef, 0xe6, 0x3d, 0xff, 
	0xff, 0xff, 0xff, 0xb7, 0xff, 0x76, 0xf3, 0xff, 
	0xff, 0xff, 0xff, 0xfe, 0x7b, 0x7f, 0xbe, 0xed, 
	0xff, 0x9d, 0x79, 0xdf, 0xff, 0xbf, 0xf9, 0xf7, 
	0x1d, 0x7f, 0x9f, 0xf9, 0xff, 0x3f, 0xff, 0x3c, 
	0xff, 0xfc, 0xb3, 0xdf, 0x7e, 0x7f, 0x67, 0xe4, 
	0xef, 0xfe, 0xfb, 0xed, 0x33, 0xff, 0xbe, 0xf3, 
	0xef, 0x75, 0xff, 0xbd, 0xc6, 0x9f, 0x7f, 0xb4, 
	0x99, 0xb6, 0xbf, 0x98, 0xfb, 0xff, 0xff, 0x3f, 
	0xbf, 0xff, 0xff, 0xff, 0x7f, 0xff, 0xff, 0xef, 
	0xbf, 0xff, 0xff, 0xfb, 0xec, 0xff, 0xff, 0xcf, 
	0xe6, 0xfe, 0xff, 0xff, 0xef, 0xff, 0xff, 0xff, 
	0xff, 0xf6, 0xff, 0x7f, 0xff, 0xf7, 0xff, 0x77, 
	0xff, 0xfe, 0xff, 0xff, 0xbb, 0xa9, 0xff, 0x5a, 
	0x7b, 0xff, 0xfd, 0xf8, 0xfa, 0x1b, 0xaf, 0x7f, 
	0xfd, 0xf4, 0x1e, 0x7a, 0xf8, 0xeb, 0xfc, 0xbf, 
	0xef, 0x6e, 0xd8, 0xf7, 0xfb, 0xae, 0xab, 0x75, 
	0xbf, 0xfa, 0x66, 0xbb, 0x5f, 0x7d, 0xf9, 0xcc, 
	0x1f, 0xff, 0xfc, 0xd1, 0x45, 0xdf, 0x9b, 0xff, 
	0xfd, 0xff, 0xde, 0xbb, 0xaf, 0xed, 0xff, 0xfa, 
	0x7a, 0xf7, 0x5d, 0xff, 0xfd, 0xd7, 0xdf, 0x7f, 
	0xb7, 0xdf, 0xff, 0xe6, 0xff, 0xeb, 0xb3, 0x8b, 
	0x2f, 0xff, 0xf8, 0xb1, 0x87, 0x3f, 0xf7, 0xf1, 
	0xc7, 0x9e, 0x7d, 0xfc, 0xf0, 0x47, 0x97, 0xbf, 
	0xf9, 0xef, 0xfa, 0xfb, 0xbf, 0xff, 0xfc, 0xfb, 
	0xf9, 0xb7, 0xff, 0xfd, 0xef, 0x9f, 0x7f, 0xff, 
	0xfb, 0xf4, 0xff, 0xfd, 0x6f, 0xf8, 0xff, 0xfe, 
	0xfe, 0xfa, 0xfa, 0xff, 0xfe, 0x7e, 0xff, 0xdf, 
	0xff, 0xfb, 0xed, 0xdf, 0xff, 0x7e, 0xfd, 0xf5, 
	0xed, 0x9b, 0xff, 0xff, 0xff, 0xee, 0xfb, 0xcb, 
	0xff, 0xf7, 0xfe, 0xfb, 0xfb, 0xff, 0xff, 0xfd, 
	0xf7, 0xdf, 0xfb, 0xff, 0xff, 0xbd, 0x66, 0xff, 
	0x7b, 0xbf, 0xbd, 0xe7, 0xf3, 0x7f, 0xbf, 0xf5, 
	0xf7, 0xbf, 0xbf, 0xdf, 0xfb, 0xed, 0xbd, 0xff, 
	0x5e, 0xf3, 0xbf, 0xf9, 0xff, 0xee, 0xdb, 0xef, 
	0xee, 0xfb, 0xf6, 0xff, 0xff, 0xbf, 0x7f, 0xcd, 
	0xff, 0xff, 0xdf, 0xf9, 0xe9, 0xa7, 0xff, 0x6b, 
	0xfa, 0xbf, 0xeb, 0xae, 0xba, 0xf4, 0xb8, 0xc1, 
	0xaf, 0xbf, 0xea, 0x35, 0x97, 0x5f, 0x3d, 0xfd, 
	0xc5, 0x06, 0x5b, 0xfe, 0x9a, 0xff, 0x3e, 0xbb, 
	0x7c, 0xf3, 0xcf, 0xee, 0xfe, 0xfc, 0xbf, 0x7f, 
	0xde, 0xb5, 0xbb, 0xf7, 0x7f, 0x7f, 0xfe, 0xfd, 
	0xdf, 0xc6, 0xff, 0xde, 0x6f, 0xab, 0xaf, 0xf5, 
	0xdf, 0xa7, 0xff, 0xad, 0xff, 0xfd, 0xde, 0xff, 
	0xaf, 0x5f, 0xef, 0xff, 0xbd, 0x9a, 0xe9, 0xfe, 
	0xfa, 0xf7, 0xdc, 0xfd, 0xfe, 0xbf, 0x5f, 0xff, 
	0xfb, 0x7f, 0xff, 0xff, 0xbf, 0xbd, 0xff, 0xdb, 
	0xd9, 0xff, 0x6f, 0xfc, 0xbf, 0xff, 0xbf, 0xcf, 
	0x8f, 0xfe, 0xbe, 0x77, 0xef, 0x7f, 0x3e, 0xed, 
	0xef, 0xff, 0xff, 0x5d, 0xfa, 0x7f, 0xdf, 0x9b, 
	0xff, 0x7f, 0xfd, 0xff, 0xfd, 0xfe, 0xf7, 0xff, 
	0xbf, 0xfe, 0xff, 0x5f, 0xff, 0x77, 0xff, 0xfd, 
	0xff, 0xf7, 0xff, 0xef, 0xe6, 0xff, 0xff, 0xbf, 
	0xff, 0xff, 0x7e, 0xeb, 0x9e, 0xff, 0xb6, 0xe5, 
	0xbd, 0xff, 0xff, 0x9f, 0xbf, 0xff, 0x7f, 0xfb, 
	0xbf, 0xf9, 0xdf, 0x3e, 0xd3, 0x6f, 0xfe, 0xfd, 
	0xf7, 0xff, 0x87, 0xff, 0xff, 0xff, 0xd3, 0xde, 
	0x3f, 0xfd, 0xbd, 0xe7, 0xff, 0x6f, 0xfe, 0xff, 
	0xfe, 0xde, 0xfa, 0xfd, 0xfe, 0xd5, 0xef, 0xff, 
	0xf7, 0xea, 0xb7, 0xff, 0xdf, 0xee, 0xff, 0x7d, 
	0xbd, 0xff, 0x9b, 0xff, 0xed, 0xfb, 0xff, 0xf4, 
	0x7d, 0xfb, 0xfb, 0x9f, 0x70, 0xff, 0xdf, 0xff, 
	0xfb, 0x5e, 0xf7, 0xbd, 0xf8, 0xff, 0xff, 0xe6, 
	0xbf, 0xfb, 0xff, 0x3f, 0xff, 0xdf, 0xff, 0xf7, 
	0xfe, 0xe5, 0xff, 0xf7, 0xf7, 0xff, 0xff, 0xfd, 
	0xef, 0xff, 0xff, 0xbf, 0xa9, 0xff, 0xba, 0xdf, 
	0xbf, 0xf7, 0xfb, 0xbf, 0xaf, 0x3f, 0xef, 0xbb, 
	0xfe, 0xdf, 0xfb, 0xcf, 0x9d, 0xdf, 0xd6, 0xff, 
	0x6e, 0xfe, 0xdf, 0x7e, 0xa3, 0xc5, 0xff, 0xbf, 
	0xfe, 0x98, 0xe3, 0xf7, 0xf3, 0xeb, 0xd7, 0xdf, 
	0x7e, 0xfe, 0xed, 0xff, 0xbf, 0x99, 0xff, 0xdf, 
	0x5f, 0x7b, 0xbb, 0xff, 0xff, 0xff, 0xef, 0xaf, 
	0xff, 0xff, 0x7f, 0xfd, 0xf7, 0xd7, 0x7f, 0xbd, 
	0xd7, 0xff, 0x86, 0xff, 0x8f, 0x7f, 0xfe, 0xf3, 
	0xfe, 0xef, 0x6c, 0xf2, 0xf9, 0xff, 0x3f, 0xeb, 
	0xe5, 0xf7, 0x5f, 0x7e, 0xff, 0xfb, 0x8f, 0xd9, 
	0xff, 0xef, 0x5b, 0x3f, 0xbd, 0xff, 0x7a, 0xbd, 
	0xff, 0xfd, 0xff, 0xef, 0x54, 0x53, 0x7d, 0xb9, 
	0xe4, 0xff, 0xff, 0x6d, 0xfe, 0xff, 0xfe, 0x7a, 
	0xcd, 0xbf, 0xf3, 0xfe, 0x5e, 0xae, 0x7f, 0x4f, 
	0xbd, 0xf5, 0xd6, 0x5b, 0x6f, 0xfd, 0xff, 0xff, 
	0x9b, 0xf5, 0xff, 0xb3, 0xcf, 0x38, 0xff, 0xef, 
	0xb3, 0xcf, 0xfa, 0xf7, 0x53, 0xaf, 0xbf, 0xfe, 
	0xfa, 0xeb, 0x67, 0xfd, 0xd7, 0xe6, 0xf6, 0xeb, 
	0xb6, 0x97, 0x70, 0x7e, 0x5d, 0xe5, 0xd7, 0x6f, 
	0x35, 0xfb, 0x5f, 0x7b, 0xed, 0xb5, 0xd7, 0xfe, 
	0xff, 0xbb, 0x99, 0xff, 0x6f, 0xbd, 0xb6, 0x8e, 
	0x7b, 0xf3, 0xb9, 0xf6, 0x56, 0xcd, 0xde, 0x7f, 
	0xff, 0xfd, 0xf7, 0xdf, 0xd7, 0xed, 0x6c, 0xec, 
	0xbf, 0xfe, 0x3b, 0x7b, 0xbb, 0xed, 0x1d, 0xfe, 
	0xeb, 0x7f, 0x7b, 0xbd, 0xbf, 0xfe, 0xeb, 0xaf, 
	0xe7, 0xff, 0xbf, 0x99, 0xf9, 0xff, 0xbf, 0xde, 
	0x0a, 0x7f, 0x7d, 0x96, 0xff, 0xfa, 0xf7, 0x5f, 
	0x0f, 0x25, 0x14, 0x56, 0x5a, 0x7b, 0xfd, 0xef, 
	0xa6, 0xfd, 0xff, 0xfe, 0xef, 0xed, 0xbf, 0xfe, 
	0xfc, 0xff, 0xff, 0x7f, 0xfe, 0xdf, 0x7e, 0xdb, 
	0x6d, 0xbd, 0xfd, 0xb7, 0xbd, 0x79, 0xff, 0xff, 
	0xfd, 0x79, 0xc6, 0x5f, 0x77, 0xff, 0xff, 0xe7, 
	0xff, 0xdd, 0x37, 0xdf, 0x60, 0x83, 0x0d, 0x7e, 
	0x7f, 0x6f, 0xec, 0xff, 0xf6, 0x7b, 0x8d, 0xbf, 
	0xdb, 0x6c, 0xfb, 0xed, 0x7f, 0x7f, 0xfd, 0xe5, 
	0x92, 0x4b, 0x2e, 0xb1, 0xf6, 0xbf, 0x99, 0xf9, 
	0xf7, 0xff, 0x7f, 0xff, 0xff, 0xfe, 0xdb, 0x6f, 
	0xff, 0xff, 0xdf, 0x3f, 0xfb, 0xcc, 0x37, 0xcf, 
	0xbc, 0xff, 0xcf, 0xe6, 0xbe, 0xff, 0xff, 0xfb, 
	0xff, 0xff, 0xff, 0xfb, 0xef, 0xff, 0xff, 0x7f, 
	0xdb, 0x74, 0xf3, 0x4d, 0xb7, 0xf7, 0xff, 0xbb, 
	0xa9, 0xff, 0xff, 0xeb, 0xbd, 0xfd, 0xff, 0xe6, 
	0xef, 0xb7, 0x7f, 0xfd, 0xff, 0x3f, 0x5a, 0x38, 
	0xa9, 0x85, 0xff, 0xff, 0x6a, 0xde, 0xdf, 0xfd, 
	0xf3, 0x9d, 0xaf, 0xb6, 0xf9, 0xf6, 0xcb, 0x5d, 
	0xfd, 0xf3, 0xdf, 0x3f, 0xff, 0xfc, 0xf3, 0x5f, 
	0xdf, 0x9b, 0xff, 0xbf, 0xdf, 0xce, 0x3f, 0xef, 
	0xee, 0xda, 0xde, 0xff, 0xff, 0xef, 0xff, 0xb7, 
	0xff, 0xff, 0xff, 0xff, 0xfd, 0xff, 0xe6, 0xfd, 
	0xff, 0xa3, 0xcf, 0x3f, 0x3e, 0xfc, 0xf3, 0xcf, 
	0x2f, 0xff, 0xf9, 0xe1, 0x17, 0x39, 0x74, 0x91, 
	0x47, 0x9f, 0xbf, 0xf9, 0xff, 0xf3, 0x9d, 0xff, 
	0xff, 0x7c, 0xe6, 0xef, 0x2f, 0xff, 0xfd, 0x45, 
	0xfb, 0xff, 0xbc, 0xf3, 0xef, 0xd7, 0xff, 0x6f, 
	0xfe, 0xff, 0x3c, 0xfb, 0xff, 0xef, 0x8f, 0xff, 
	0xfe, 0xcb, 0xdb, 0x5f, 0x7d, 0x7e, 0xd5, 0x5f, 
	0x5f, 0xfd, 0xf5, 0xff, 0x9b, 0xfd, 0xff, 0xef, 
	0xfe, 0xff, 0xcf, 0xe8, 0xff, 0xfe, 0xbf, 0xda, 
	0x57, 0xcf, 0xff, 0xf5, 0xd6, 0x5d, 0xfe, 0xff, 
	0xff, 0xe6, 0xff, 0xdf, 0x7c, 0xff, 0xf7, 0x16, 
	0x5b, 0x6f, 0xff, 0xed, 0x3d, 0xd7, 0xfa, 0xf3, 
	0xef, 0xbf, 0xff, 0xfe, 0xfb, 0xbf, 0xf9, 0xff, 
	0xf4, 0xd3, 0x7f, 0xb7, 0xfd, 0xf2, 0xdb, 0x7b, 
	0xbd, 0xff, 0xff, 0xb7, 0xdf, 0x7e, 0xfb, 0xa9, 
	0xb7, 0xf3, 0x6d, 0xfa, 0xef, 0xab, 0xae, 0xbe, 
	0xda, 0xea, 0xcb, 0x25, 0xbe, 0xf8, 0xd5, 0x97, 
	0x5d, 0x7b, 0xf4, 0xf5, 0x57, 0x5d, 0xfd, 0x9a, 
	0xff, 0x1f, 0xff, 0xff, 0xf6, 0xcb, 0xdf, 0xbf, 
	0xfd, 0xfe, 0xff, 0xfd, 0x57, 0xe9, 0xe9, 0xc7, 
	0x3f, 0x7e, 0xff, 0xff, 0xc6, 0xff, 0x7f, 0xff, 
	0x9b, 0x6f, 0xbd, 0xff, 0x6a, 0xfb, 0xff, 0x3f, 
	0xfb, 0xb7, 0x7f, 0xd7, 0xf7, 0xd3, 0xef, 0xbf, 
	0x9f, 0xd9, 0xfb, 0xe2, 0xff, 0xf7, 0xff, 0xf6, 
	0xbf, 0xff, 0x7f, 0xfe, 0xff, 0xbe, 0xef, 0xff, 
	0xff, 0x7f, 0xbf, 0xfb, 0xff, 0x6f, 0xf6, 0x3e, 
	0x5e, 0xfa, 0x7f, 0x8e, 0xff, 0x5f, 0xf8, 0x6e, 
	0x7f, 0xfd, 0xfd, 0x7f, 0xbb, 0xef, 0xbe, 0xf9, 
	0xe9, 0xfb, 0x9b, 0xff, 0xff, 0xbf, 0xbe, 0xff, 
	0xf5, 0xff, 0x7f, 0x6f, 0xfe, 0x7f, 0xdf, 0xdf, 
	0xbf, 0xff, 0xff, 0xff, 0xdf, 0xff, 0xff, 0xe6, 
	0x6f, 0xcb, 0xfe, 0x7d, 0xd4, 0xbb, 0xfd, 0x1f, 
	0xfb, 0xbe, 0x7c, 0xcf, 0xfd, 0xff, 0xbf, 0x7e, 
	0xf7, 0xfd, 0xf7, 0xbf, 0xf9, 0xff, 0xff, 0xfa, 
	0xff, 0x3e, 0xff, 0xf6, 0xff, 0xcf, 0x77, 0xff, 
	0xed, 0xff, 0x5f, 0x76, 0xf3, 0xf5, 0xb6, 0xff, 
	0x6f, 0xee, 0xf7, 0x7d, 0x5e, 0xff, 0xbf, 0xbe, 
	0xff, 0x5f, 0xef, 0xc7, 0x1f, 0xf7, 0xbf, 0xff, 
	0x7c, 0xff, 0xef, 0xf7, 0xff, 0x9a, 0xff, 0x4e, 
	0xfe, 0xef, 0xff, 0x69, 0xf7, 0xd6, 0x6f, 0xfd, 
	0xf7, 0x9e, 0xff, 0x7e, 0xff, 0xff, 0xfb, 0xfd, 
	0xff, 0xdf, 0xe6, 0xff, 0xf3, 0xfc, 0xff, 0xd7, 
	0xdf, 0xff, 0xff, 0x6f, 0xff, 0xfd, 0xde, 0x7f, 
	0xdf, 0x7f, 0xff, 0xfd, 0xf7, 0xff, 0xbf, 0xf9, 
	0xff, 0xfb, 0xde, 0xad, 0xfb, 0xff, 0xfa, 0xe9, 
	0xbc, 0xfb, 0xdf, 0xf3, 0xfa, 0x7d, 0xee, 0xfb, 
	0xe7, 0x3d, 0xff, 0x6f, 0xfc, 0x3f, 0x6c, 0xf2, 
	0xad, 0xbf, 0xff, 0xff, 0xf3, 0xe7, 0x57, 0xff, 
	0xbd, 0xbf, 0xdf, 0x76, 0xdf, 0xed, 0xf7, 0xff, 
	0x99, 0xfd, 0xff, 0xff, 0xf7, 0xed, 0xef, 0xff, 
	0x7f, 0xff, 0xfd, 0xff, 0x8f, 0xfd, 0xff, 0xf5, 
	0x5e, 0x5e, 0xff, 0xf5, 0xff, 0xa6, 0x7f, 0xbd, 
	0xaf, 0xbe, 0xc1, 0xef, 0xcb, 0xef, 0xff, 0xc1, 
	0xcf, 0xff, 0xf9, 0xfd, 0xff, 0xff, 0xff, 0xff, 
	0xff, 0x8f, 0xd9, 0xcf, 0xf3, 0xbf, 0xef, 0xf2, 
	0xff, 0xfa, 0xeb, 0xf5, 0xd7, 0xfb, 0xff, 0x7a, 
	0x5f, 0x7f, 0xfd, 0xf5, 0xd7, 0xff, 0x6d, 0xfe, 
	0xff, 0x9f, 0x7f, 0xfa, 0xa5, 0xbe, 0xfe, 0xda, 
	0x3f, 0x7f, 0xe7, 0xef, 0xff, 0xd6, 0x5b, 0x6f, 
	0xbd, 0xf5, 0xff, 0x9b, 0xf5, 0xfc, 0xb7, 0xde, 
	0x7e, 0xea, 0xac, 0xb3, 0xfe, 0x3f, 0xd7, 0xfb, 
	0xff, 0xbf, 0xfe, 0xfa, 0xeb, 0xaf, 0xff, 0xd7, 
	0xe6, 0xfe, 0x7d, 0xf3, 0xed, 0xfd, 0x53, 0xcd, 
	0xaf, 0xff, 0x5e, 0xff, 0xd0, 0xea, 0x7b, 0xcd, 
	0xb4, 0xd2, 0x4a, 0xab, 0xbb, 0x99, 0x3f, 0xef, 
	0x68, 0xff, 0xbe, 0x6d, 0xf6, 0xa9, 0xef, 0xd6, 
	0xd7, 0xd4, 0xff, 0xff, 0xab, 0xef, 0x3f, 0xfb, 
	0xec, 0x6c, 0xec, 0xef, 0xb2, 0xfa, 0xef, 0xfd, 
	0xff, 0xb6, 0x7e, 0xef, 0xff, 0x7b, 0x9d, 0xbf, 
	0xff, 0xff, 0xff, 0xff, 0xff, 0xbf, 0x99, 0xf9, 
	0xbf, 0xfd, 0xf7, 0xf3, 0x3e, 0x2f, 0xff, 0x8e, 
	0xfe, 0xff, 0xdf, 0xed, 0xe7, 0xf5, 0xd7, 0x5f, 
	0x7f, 0xfd, 0xef, 0x46, 0xfd, 0xdf, 0xf6, 0xdb, 
	0xff, 0xb7, 0xdf, 0xff, 0xff, 0xcf, 0x7f, 0xbb, 
	0xf7, 0x7e, 0xdf, 0x7d, 0xf7, 0xfd, 0xf7, 0xbd, 
	0x79, 0xf7, 0x47, 0xff, 0x7d, 0xfe, 0x7f, 0xef, 
	0xff, 0xf9, 0xf7, 0xbf, 0xcf, 0x37, 0xdf, 0x67, 
	0x9f, 0x7d, 0xf6, 0x79, 0x6f, 0xe8, 0xff, 0x38, 
	0xbb, 0x8f, 0x3f, 0xd7, 0x58, 0xfb, 0xed, 0x74, 
	0xb7, 0xf9, 0xe5, 0xd2, 0x5f, 0x2f, 0xfd, 0xf5, 
	0xbb, 0x99, 0xf9, 0xf7, 0xce, 0x7f, 0xff, 0xfd, 
	0xf7, 0xff, 0x6f, 0xff, 0xfd, 0xe7, 0x7f, 0xff, 
	0xec, 0xb3, 0xcf, 0x3e, 0x7b, 0x4e, 0xe6, 0xfe, 
	0xfe, 0xfb, 0xef, 0xbf, 0xbf, 0xff, 0xff, 0xf7, 
	0xef, 0x7f, 0x7f, 0xff, 0x75, 0xdb, 0xed, 0xb5, 
	0xdb, 0xde, 0xbb, 0xb9, 0xff, 0xd6, 0x7f, 0xef, 
	0xfc, 0xff, 0xf3, 0xeb, 0xaf, 0xff, 0xfd, 0xce, 
	0x3f, 0xfe, 0x7f, 0xfd, 0xf5, 0xd7, 0xfb, 0x6a, 
	0xde, 0x97, 0xf9, 0xea, 0x9b, 0x67, 0xb6, 0x5a, 
	0xf2, 0xcb, 0x57, 0xfe, 0xf3, 0xcf, 0x56, 0xfb, 
	0xed, 0xf7, 0xdf, 0xce, 0x9b, 0xff, 0xb7, 0xbf, 
	0xfe, 0xee, 0xeb, 0xbf, 0xbf, 0xfe, 0xfb, 0xff, 
	0xff, 0xad, 0xfb, 0xf5, 0xff, 0xff, 0xff, 0xbf, 
	0xff, 0xe6, 0xff, 0xff, 0xf0, 0x8f, 0x3f, 0x3e, 
	0xf8, 0xa3, 0x8f, 0x2e, 0x7f, 0xd9, 0xe3, 0x9f, 
	0x7f, 0xf4, 0xd1, 0x47, 0x1f, 0xbf, 0xf9, 0xff, 
	0xfe, 0xe9, 0xbf, 0xff, 0x7c, 0xfb, 0x9f, 0x2f, 
	0x7f, 0xfd, 0xef, 0xd3, 0xff, 0xff, 0xff, 0xff, 
	0xff, 0xff, 0x6f, 0xfe, 0xbf, 0x1f, 0xff, 0xff, 
	0x7f, 0x8b, 0xff, 0xfb, 0xcb, 0x5b, 0xdf, 0x7b, 
	0xf4, 0xd7, 0x5f, 0x7f, 0xfd, 0xf5, 0xff, 0x9b, 
	0xff, 0xbf, 0xeb, 0xff, 0xfb, 0xef, 0xb9, 0xbf, 
	0xff, 0xbf, 0xfa, 0xf5, 0x4f, 0xfd, 0xf5, 0xd7, 
	0x5f, 0x7f, 0xfd, 0xff, 0xe6, 0xff, 0x7f, 0xad, 
	0xfd, 0xf7, 0x12, 0x7b, 0x3f, 0xff, 0xed, 0xee, 
	0xff, 0x58, 0xfb, 0xef, 0xbf, 0xff, 0xfe, 0xfb, 
	0xbf, 0xf9, 0xff, 0xff, 0xfb, 0x4f, 0xff, 0xff, 
	0xf6, 0xff, 0xff, 0xbf, 0xea, 0xc9, 0xff, 0xdf, 
	0x6d, 0xff, 0xbd, 0x77, 0xff, 0x6f, 0xfa, 0xf7, 
	0xeb, 0xae, 0xbb, 0xfa, 0xfa, 0xc9, 0x8f, 0xbf, 
	0xe6, 0xf5, 0xd7, 0x5f, 0x6f, 0xbd, 0x75, 0x57, 
	0x5d, 0xff, 0x9b, 0xbf, 0xbf, 0xfd, 0x7c, 0xe3, 
	0xef, 0xcf, 0xfb, 0xff, 0xaf, 0xff, 0xbf, 0xcf, 
	0xd9, 0xff, 0xfb, 0xff, 0xff, 0xf7, 0xdf, 0x46, 
	0xff, 0xfd, 0xf7, 0xf7, 0x7f, 0xd7, 0xfe, 0xfa, 
	0xfd, 0xaf, 0xff, 0xff, 0xbf, 0xef, 0xff, 0x7f, 
	0xff, 0xff, 0xff, 0x9f, 0xf9, 0xef, 0xcb, 0xeb, 
	0xaf, 0xed, 0xfe, 0xbf, 0xff, 0xff, 0xfc, 0xf3, 
	0x7f, 0x6b, 0xfe, 0xff, 0xf7, 0xae, 0xfb, 0xe7, 
	0x67, 0xfe, 0xf7, 0xdb, 0xa4, 0xcf, 0xaf, 0x2f, 
	0xd8, 0xfa, 0xee, 0x5f, 0xee, 0xf5, 0xf5, 0x7e, 
	0x7f, 0x7f, 0xff, 0xf7, 0x7f, 0x99, 0x7d, 0xfb, 
	0xff, 0xff, 0xdf, 0xea, 0xef, 0x9f, 0x7e, 0xbf, 
	0xb5, 0xff, 0x5f, 0xfb, 0xff, 0xff, 0xff, 0x7c, 
	0xff, 0x7f, 0xe6, 0xff, 0xff, 0x9e, 0xbf, 0xee, 
	0xf3, 0xa7, 0x17, 0xb4, 0xdd, 0x3e, 0x57, 0x3e, 
	0xf7, 0xb8, 0xbd, 0xff, 0xff, 0xff, 0x9f, 0xd9, 
	0xfb, 0xff, 0xcb, 0x8f, 0xbf, 0xdf, 0xfe, 0xff, 
	0xef, 0xff, 0xdf, 0xe1, 0xbf, 0xf7, 0xff, 0xff, 
	0xbd, 0xf7, 0xff, 0x6f, 0xfe, 0xf7, 0xff, 0xff, 
	0xff, 0x6d, 0xfd, 0xf6, 0xff, 0xba, 0xed, 0xfb, 
	0xbf, 0xbf, 0xff, 0xff, 0x79, 0xbf, 0xfc, 0xff, 
	0x9b, 0xff, 0xff, 0x1b, 0xbf, 0xee, 0xf3, 0xcd, 
	0xff, 0xfd, 0xed, 0xff, 0xf7, 0xff, 0xff, 0x6f, 
	0xf3, 0xef, 0xbf, 0xff, 0xff, 0xe6, 0xff, 0xfe, 
	0x7f, 0xbf, 0xef, 0xb7, 0xeb, 0xff, 0x6f, 0x77, 
	0xff, 0xff, 0xff, 0xff, 0xff, 0xfd, 0xff, 0xfe, 
	0xff, 0xbf, 0xb9, 0xff, 0x5b, 0xe3, 0xff, 0x7f, 
	0xff, 0xff, 0xfe, 0xff, 0x77, 0xfd, 0x77, 0xdb, 
	0xfd, 0xff, 0x7f, 0xff, 0xff, 0xff, 0x6f, 0xfc, 
	0x7d, 0xdf, 0xbf, 0x6f, 0xbf, 0xff, 0xfb, 0xfa, 
	0xcb, 0xfb, 0xde, 0xfe, 0xb1, 0xfb, 0xff, 0x7f, 
	0xf5, 0xf5, 0xff, 0x9b, 0x7a, 0xff, 0xff, 0xf3, 
	0xfb, 0xef, 0xff, 0xff, 0xdf, 0xff, 0xff, 0xff, 
	0xfd, 0xff, 0xff, 0xff, 0xff, 0xf3, 0xff, 0xff, 
	0x86, 0x7f, 0xde, 0x7f, 0xbc, 0xf1, 0xef, 0xef, 
	0x7c, 0xbf, 0xf1, 0xff, 0x3c, 0x7f, 0xa8, 0xfb, 
	0xf7, 0xf7, 0xdf, 0xff, 0x8f, 0xd9, 0xcf, 0xfe, 
	0xdb, 0xbf, 0xbe, 0xfc, 0x3b, 0xff, 0x3f, 0xff, 
	0xff, 0xdd, 0x5f, 0xeb, 0xff, 0xfd, 0xf5, 0xff, 
	0xff, 0x6d, 0xfe, 0xa7, 0xfe, 0xfa, 0x7b, 0xa5, 
	0xe7, 0x9f, 0x7e, 0xfa, 0xf9, 0xcf, 0xff, 0xf7, 
	0xf2, 0x7f, 0x7f, 0x3f, 0xff, 0xff, 0x9b, 0xf5, 
	0xed, 0xb7, 0xff, 0xfb, 0xff, 0xbc, 0xa7, 0xdf, 
	0x3b, 0xf7, 0xd9, 0xe7, 0x3d, 0xff, 0xdf, 0x5f, 
	0x6f, 0xff, 0xd7, 0xe6, 0xfe, 0xee, 0x3b, 0xdb, 
	0x6f, 0xfa, 0x6f, 0xf6, 0xaf, 0xff, 0xff, 0xfb, 
	0xed, 0xff, 0xbf, 0xb6, 0x9f, 0xd6, 0xfb, 0xbb, 
	0x99, 0xff, 0xef, 0xb9, 0xf5, 0xd6, 0x7f, 0xab, 
	0xfd, 0xf6, 0xd6, 0x77, 0xde, 0x5b, 0x6f, 0xbd, 
	0xf5, 0x5f, 0xdb, 0xec, 0x6c, 0xec, 0xff, 0x9e, 
	0x72, 0xff, 0xff, 0xef, 0xda, 0x53, 0xfb, 0xdf, 
	0x5f, 0x7f, 0xff, 0xf5, 0x73, 0xf9, 0xfd, 0xf7, 
	0xbf, 0x99, 0xfb, 0xaf, 0xaf, 0xbe, 0xff, 0x6b, 
	0xff, 0xa1, 0x8d, 0xfb, 0xd7, 0xdf, 0xff, 0xff, 
	0xf7, 0xd8, 0xf9, 0xfc, 0xff, 0x8f, 0xe6, 0xfd, 
	0xff, 0xfc, 0xdb, 0x6f, 0xbf, 0xdf, 0x7c, 0xfb, 
	0xff, 0xff, 0xff, 0xfd, 0xff, 0xff, 0x6f, 0xbf, 
	0xed, 0xb7, 0xbd, 0x79, 0xff, 0xff, 0xbf, 0xff, 
	0xff, 0x5b, 0x67, 0xff, 0xf5, 0xff, 0x3f, 0xff, 
	0xfa, 0xff, 0xcd, 0x33, 0xee, 0xff, 0x7f, 0x6f, 
	0xec, 0xd7, 0x7e, 0xe3, 0xef, 0xb5, 0xfb, 0x38, 
	0xbb, 0xef, 0x77, 0xbf, 0xdd, 0xf7, 0xdb, 0x6f, 
	0xfc, 0xfd, 0xf7, 0xbf, 0x99, 0xf9, 0xf7, 0xcf, 
	0x7f, 0xff, 0xfd, 0xf7, 0xfb, 0xff, 0xbf, 0xfd, 
	0xe7, 0xff, 0x7f, 0xff, 0xfd, 0xff, 0xbf, 0xff, 
	0xcf, 0xe6, 0xbe, 0xff, 0xfb, 0xef, 0xbf, 0x7f, 
	0xff, 0xff, 0xff, 0xdf, 0xff, 0xfd, 0xff, 0xff, 
	0xf7, 0xff, 0xff, 0xf7, 0xff, 0xbb, 0xa9, 0xff, 
	0xfb, 0x1f, 0xff, 0xbf, 0x56, 0xd3, 0xad, 0xff, 
	0xff, 0xbd, 0xf7, 0xfb, 0xff, 0xff, 0xf3, 0xfd, 
	0xf7, 0xff, 0x6a, 0xde, 0xdf, 0xfc, 0x63, 0xdd, 
	0xad, 0xba, 0xf9, 0xfa, 0xdf, 0x7f, 0xfd, 0xf9, 
	0xef, 0x3b, 0xef, 0x7c, 0xf7, 0xd7, 0xdf, 0x9b, 
	0xff, 0xbf, 0xf3, 0xfa, 0xfb, 0xef, 0xee, 0xbb, 
	0x7e, 0xbe, 0xdf, 0x7f, 0xbf, 0xbf, 0xf7, 0x5f, 
	0xdb, 0x77, 0xff, 0xef, 0xe6, 0xff, 0xef, 0xe3, 
	0x8f, 0x3f, 0xfe, 0xec, 0x63, 0xcf, 0x3e, 0xf7, 
	0xd1, 0xe7, 0x1f, 0x7f, 0xfc, 0xf1, 0x47, 0x9f, 
	0xbb, 0xf9, 0xff, 0xff, 0xff, 0x7f, 0xbf, 0xff, 
	0xf6, 0xeb, 0xbf, 0xff, 0xfd, 0xf7, 0x9f, 0xff, 
	0xff, 0xfb, 0xf7, 0xff, 0xff, 0x6f, 0xfe, 0xff, 
	0xfe, 0xff, 0xdf, 0xff, 0xff, 0xfc, 0xfa, 0xef, 
	0x5f, 0xff, 0xfd, 0xe7, 0xff, 0xff, 0xfe, 0xfd, 
	0xf7, 0xff, 0x9b, 0xff, 0xbf, 0xff, 0xff, 0xfe, 
	0xef, 0xbf, 0xbf, 0xfe, 0xfa, 0xdb, 0x7f, 0xff, 
	0xfd, 0xf7, 0xff, 0xff, 0xff, 0xfd, 0xff, 0xe6, 
	0xff, 0xdf, 0xff, 0xbd, 0xfc, 0xda, 0x7b, 0x2f, 
	0xff, 0xfe, 0xb6, 0x9f, 0x7f, 0x7e, 0xef, 0xbf, 
	0xff, 0x7e, 0xfb, 0xbf, 0xf9, 0xff, 0xf5, 0x5b, 
	0xff, 0xbf, 0xfd, 0xfe, 0xca, 0x3f, 0x3f, 0xfa, 
	0xff, 0xf7, 0xff, 0x7d, 0xf1, 0xed, 0xb7, 0xfb, 
	0x6f, 0xfa, 0xff, 0xe3, 0x2f, 0xbd, 0xd4, 0x7a, 
	0xe3, 0xad, 0xbf, 0xfa, 0xf5, 0xc3, 0x5b, 0x7f, 
	0xbd, 0x75, 0xd7, 0x5d, 0xfb, 0x9a, 0xff, 0xff, 
	0x3c, 0xff, 0xf7, 0xfb, 0x37, 0xff, 0x7f, 0x7f, 
	0xef, 0xff, 0xfe, 0xdd, 0xbf, 0x7f, 0x57, 0x7e, 
	0xf7, 0xef, 0xc6, 0xff, 0x7f, 0xff, 0xbf, 0xbf, 
	0xbf, 0xe7, 0xff, 0xf5, 0xf7, 0xff, 0x6e, 0x7e, 
	0xff, 0xfb, 0xfe, 0xd3, 0xfb, 0xff, 0x9f, 0xf9, 
	0x7f, 0xff, 0xff, 0x7f, 0xdf, 0xff, 0xdf, 0xbd, 
	0x7f, 0xfe, 0xeb, 0xff, 0xff, 0xfe, 0xff, 0xe7, 
	0xcf, 0xff, 0xff, 0x6f, 0xfa, 0xb5, 0x7e, 0xfe, 
	0xf3, 0xaf, 0xbb, 0xfe, 0xd8, 0xff, 0x7f, 0x7d, 
	0xf5, 0xf1, 0xff, 0x5f, 0x7e, 0xfe, 0xf9, 0xff, 
	0x9a, 0xff, 0xbb, 0xff, 0xf5, 0xff, 0xdb, 0x55, 
	0x7f, 0xef, 0xbf, 0xff, 0x7d, 0xd7, 0xf7, 0xff, 
	0xd7, 0xff, 0xf7, 0xdf, 0xfe, 0xe6, 0xff, 0xfb, 
	0x9c, 0xeb, 0xef, 0xe9, 0xff, 0xff, 0x7e, 0xfe, 
	0xfd, 0xc7, 0xdf, 0xf7, 0x7b, 0xf3, 0xdd, 0xff, 
	0xff, 0xbf, 0xf9, 0xff, 0xe7, 0xcb, 0x7f, 0xff, 
	0xff, 0xff, 0x7f, 0xe7, 0xff, 0x37, 0xb5, 0xf7, 
	0xdf, 0x7f, 0xf9, 0xf1, 0xff, 0xff, 0x6f, 0xbe, 
	0xef, 0xff, 0xdf, 0xff, 0xff, 0xf7, 0xff, 0x7f, 
	0xaf, 0xfd, 0xff, 0xaf, 0xf7, 0xde, 0xff, 0xff, 
	0xff, 0xff, 0xff, 0x9b, 0xef, 0xff, 0xfc, 0xff, 
	0x8f, 0xfe, 0xcf, 0xdf, 0xef, 0xf5, 0xff, 0xf7, 
	0xff, 0xef, 0x5d, 0xa7, 0xf7, 0xef, 0xff, 0xff, 
	0xe6, 0xfb, 0xbf, 0xf3, 0xf6, 0xdf, 0xff, 0xef, 
	0xff, 0xff, 0xfd, 0xbf, 0xfd, 0xff, 0x7f, 0xbf, 
	0xf9, 0xff, 0xff, 0xff, 0xbf, 0xf9, 0xff, 0xff, 
	0xdf, 0xfe, 0xbf, 0x5e, 0xfd, 0xde, 0xbf, 0xd7, 
	0xbf, 0xef, 0xfb, 0xff, 0xaf, 0xff, 0x7f, 0xff, 
	0xf7, 0x6f, 0xfc, 0xdf, 0xfe, 0xf2, 0x6b, 0xbf, 
	0xff, 0xfb, 0xfa, 0xe7, 0xfc, 0xff, 0xef, 0xd7, 
	0xdf, 0x7e, 0xff, 0xff, 0xdf, 0x7f, 0x99, 0xff, 
	0xbf, 0xff, 0xf7, 0xff, 0xef, 0xff, 0xff, 0xf3, 
	0x7b, 0x7f, 0xff, 0xbf, 0xf5, 0xf7, 0xef, 0xff, 
	0xff, 0xff, 0xff, 0xe6, 0x7d, 0x9e, 0xaf, 0xe7, 
	0xff, 0x7f, 0x1d, 0x7f, 0xfe, 0xf8, 0xcf, 0x3f, 
	0x7f, 0xa8, 0xff, 0xfd, 0xfc, 0xff, 0xff, 0xaf, 
	0x99, 0x9f, 0xff, 0xff, 0xf5, 0xff, 0xf7, 0x7f, 
	0xbd, 0x6f, 0x7f, 0xf7, 0xdf, 0xf4, 0xff, 0xfb, 
	0xff, 0xff, 0xff, 0xff, 0x69, 0xfe, 0xff, 0xf1, 
	0xff, 0xff, 0xff, 0xff, 0xf3, 0x77, 0xee, 0xff, 
	0x2f, 0xff, 0x97, 0xd2, 0xeb, 0xff, 0x3f, 0xf5, 
	0x7f, 0x1b, 0xf4, 0xdf, 0xa6, 0xfe, 0x3f, 0xff, 
	0xdf, 0x7f, 0xfd, 0xff, 0xf7, 0xdb, 0x7f, 0xbf, 
	0xff, 0xfe, 0xff, 0x7f, 0xfd, 0x57, 0xe6, 0xfe, 
	0xdf, 0xef, 0xd5, 0xff, 0xff, 0xff, 0xff, 0xff, 
	0x5f, 0xff, 0xf9, 0x7f, 0x9f, 0x2f, 0xbc, 0xd3, 
	0xff, 0xff, 0xbb, 0x99, 0xff, 0xff, 0x6f, 0xf6, 
	0xff, 0x5a, 0xff, 0xff, 0xff, 0x56, 0x77, 0x7e, 
	0x7b, 0x65, 0xbd, 0x77, 0xd4, 0x7f, 0xff, 0x6c, 
	0x2c, 0xff, 0xc7, 0xfb, 0xff, 0xff, 0xff, 0xcd, 
	0x37, 0xef, 0xf5, 0x5f, 0xfb, 0xf7, 0xd7, 0xd6, 
	0x5f, 0xfd, 0xf5, 0xbf, 0x19, 0xd9, 0xff, 0x97, 
	0xf7, 0xff, 0xff, 0xff, 0xf3, 0xdf, 0x7e, 0xf7, 
	0x5f, 0xe7, 0xff, 0xd7, 0x5f, 0x59, 0x7f, 0xfd, 
	0x4f, 0x66, 0xfd, 0xdf, 0xfe, 0xfb, 0xff, 0xff, 
	0xff, 0xff, 0xef, 0xbf, 0xff, 0xff, 0xf9, 0xb7, 
	0xfb, 0x6f, 0xff, 0xff, 0xff, 0xb5, 0x79, 0xff, 
	0xff, 0xfd, 0xf5, 0xf7, 0xff, 0x7f, 0xde, 0xff, 
	0xf7, 0xff, 0xff, 0xff, 0xfb, 0xcc, 0x33, 0xfe, 
	0xff, 0x7f, 0x6f, 0xec, 0xff, 0xfe, 0x7b, 0xec, 
	0xb6, 0xdf, 0xfc, 0x7b, 0xed, 0x73, 0xbb, 0xbd, 
	0xb6, 0x99, 0x6b, 0xfe, 0xfd, 0xf7, 0xbf, 0x99, 
	0xfb, 0xf7, 0xdf, 0xff, 0xff, 0xfc, 0xf6, 0xff, 
	0x7f, 0xbf, 0xfd, 0xe7, 0xff, 0xdf, 0xfe, 0xff, 
	0xff, 0xff, 0xff, 0xef, 0xe6, 0xfe, 0xfe, 0xfd, 
	0xff, 0xbf, 0x7f, 0xff, 0xff, 0xf7, 0xdf, 0x7f, 
	0xff, 0xff, 0xdf, 0xf7, 0xdf, 0xff, 0xff, 0xff, 
	0xbb, 0xa9, 0xff, 0xee, 0x7f, 0xef, 0xbf, 0xfe, 
	0xee, 0xfb, 0xff, 0xff, 0xbf, 0xdd, 0xd7, 0xff, 
	0xfc, 0xf3, 0xff, 0xff, 0xfb, 0x6a, 0xd8, 0x9f, 
	0xfd, 0xea, 0xdb, 0x2f, 0xdf, 0xdc, 0x76, 0xdf, 
	0xf7, 0xfe, 0xf9, 0xe4, 0x3b, 0xff, 0xec, 0xff, 
	0xff, 0xdf, 0x98, 0xf7, 0xbf, 0xb6, 0xfe, 0xff, 
	0xf9, 0xfd, 0xfe, 0xfe, 0xfa, 0xff, 0xef, 0xfd, 
	0xff, 0xe7, 0x5b, 0xff, 0xff, 0xff, 0xff, 0xe6, 
	0xbf, 0xff, 0xf3, 0x8f, 0x3f, 0xfb, 0xfc, 0xb3, 
	0x8f, 0x2e, 0x7f, 0xf9, 0x63, 0x9f, 0x7d, 0xf4, 
	0xf9, 0xe7, 0x9f, 0xbf, 0xf9, 0xff, 0xf6, 0xeb, 
	0xff, 0x9f, 0xfe, 0xf3, 0x9b, 0x2f, 0xfe, 0xfd, 
	0xcd, 0xd7, 0xff, 0xff, 0xfb, 0xff, 0xff, 0xff, 
	0x6f, 0xfe, 0xbf, 0x7f, 0xff, 0xfb, 0xaf, 0x9f, 
	0xfd, 0xfe, 0xeb, 0xdf, 0xff, 0xfd, 0xf4, 0xff, 
	0xff, 0xfe, 0xff, 0xff, 0xff, 0x9b, 0xff, 0x3f, 
	0xef, 0xff, 0xff, 0xff, 0xbb, 0xff, 0xfe, 0xbe, 
	0xda, 0xf5, 0xcf, 0xff, 0xf7, 0xff, 0xff, 0xff, 
	0xff, 0xff, 0xe6, 0xff, 0xdf, 0xa0, 0xfd, 0xdd, 
	0x3b, 0xd8, 0x3f, 0xbf, 0xac, 0xfd, 0xbd, 0xe1, 
	0x7f, 0xef, 0xbd, 0xbf, 0xff, 0xff, 0xbf, 0xf9, 
	0xff, 0xff, 0xce, 0xfd, 0xbf, 0xbd, 0xff, 0xff, 
	0x7d, 0x3f, 0xfa, 0xef, 0xb7, 0xdf, 0x7e, 0xfa, 
	0xff, 0xff, 0xff, 0x6f, 0xfa, 0xff, 0xeb, 0xaf, 
	0xbd, 0xfe, 0xea, 0xa3, 0xaf, 0xbe, 0xd6, 0xc5, 
	0xd7, 0x5f, 0x7d, 0xbd, 0xd5, 0x57, 0x5f, 0xfb, 
	0x9b, 0xff, 0x7f, 0xf7, 0xff, 0xff, 0xf3, 0xff, 
	0xff, 0xf6, 0xfe, 0x9f, 0xdf, 0x7e, 0x7e, 0xd9, 
	0xff, 0xff, 0xff, 0xff, 0xff, 0x46, 0xff, 0xd7, 
	0x7f, 0xff, 0xff, 0xbf, 0xff, 0xff, 0xff, 0xeb, 
	0x9d, 0xf7, 0xff, 0xf7, 0xff, 0xbf, 0xff, 0xff, 
	0xff, 0x9f, 0xf9, 0xf7, 0xbf, 0xfd, 0xf3, 0xdf, 
	0x6f, 0xff, 0xef, 0xff, 0xf7, 0xfe, 0xee, 0xff, 
	0xf7, 0xff, 0xff, 0xff, 0xff, 0xff, 0x67, 0xfe, 
	0xf7, 0xff, 0xfe, 0xef, 0xaf, 0x37, 0xec, 0xf7, 
	0xef, 0x1f, 0xff, 0xff, 0xb4, 0xdf, 0x0f, 0xfd, 
	0xff, 0xff, 0x9f, 0x9b, 0xff, 0xfb, 0xef, 0xbe, 
	0xfe, 0xdb, 0xdf, 0xff, 0xbf, 0xfe, 0xed, 0xff, 
	0x7f, 0xf5, 0xff, 0xef, 0xf5, 0xff, 0xff, 0x7f, 
	0xe6, 0xef, 0xef, 0x7f, 0xff, 0xdc, 0xff, 0xff, 
	0x7e, 0xff, 0xfb, 0xfe, 0xff, 0xeb, 0x7f, 0xff, 
	0xff, 0xff, 0xfe, 0xff, 0xbf, 0xf9, 0xef, 0xf6, 
	0xff, 0xc5, 0xbf, 0xbc, 0xfa, 0xff, 0x7f, 0xbf, 
	0xfb, 0x6f, 0xfe, 0xff, 0xfe, 0xff, 0xff, 0xff, 
	0xff, 0x6f, 0xee, 0xff, 0xfc, 0xff, 0xef, 0xff, 
	0xff, 0xff, 0xff, 0xff, 0xee, 0xff, 0x7f, 0x7f, 
	0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0x9b, 0xfd, 
	0xff, 0xff, 0xff, 0xef, 0xff, 0xff, 0xff, 0xdf, 
	0xff, 0xff, 0xff, 0xff, 0x7f, 0xbf, 0xff, 0xff, 
	0xff, 0xff, 0x7f, 0xe6, 0xff, 0x7f, 0xff, 0xff, 
	0xff, 0xff, 0xff, 0xfe, 0xfe, 0xff, 0xff, 0xff, 
	0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xbf, 
	0xf9, 0xff, 0xfb, 0xff, 0xff, 0xff, 0xff, 0xfb, 
	0xff, 0xaf, 0xff, 0xdf, 0xff, 0xff, 0xff, 0xb5, 
	0x7f, 0xff, 0xff, 0xff, 0x6f, 0xf4, 0x3f, 0xfe, 
	0xff, 0x5e, 0xfe, 0xbf, 0xfe, 0xdf, 0x6f, 0xff, 
	0xff, 0xff, 0xff, 0xff, 0xff, 0xfe, 0xff, 0xff, 
	0xff, 0x9a, 0xff, 0xff, 0xde, 0x5f, 0xff, 0xff, 
	0xef, 0xff, 0xff, 0xfb, 0xff, 0xfe, 0xf7, 0xff, 
	0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0x66, 0xdf, 
	0x5f, 0x3f, 0xff, 0xfc, 0xf3, 0xcf, 0x3f, 0xff, 
	0xbc, 0xe7, 0x9f, 0xff, 0xfe, 0xf9, 0xe7, 0x9f, 
	0x7f, 0xfe, 0x9f, 0xf9, 0xfb, 0xf7, 0xdf, 0xb7, 
	0xdf, 0xfd, 0xf7, 0xcf, 0x3f, 0xff, 0xff, 0xe7, 
	0xbf, 0xff, 0xfe, 0xfb, 0xef, 0xbf, 0xff, 0x6f, 
	0xfe, 0xbf, 0x7c, 0xfb, 0xef, 0x8f, 0xff, 0xfe, 
	0xdb, 0xeb, 0x1b, 0x7f, 0xf4, 0xf7, 0xdf, 0x7f, 
	0xff, 0xbd, 0xf7, 0xff, 0x9b, 0xff, 0xf7, 0xff, 
	0xf7, 0xf7, 0x7f, 0xfe, 0xff, 0xff, 0xdf, 0xfa, 
	0x7f, 0xfb, 0xff, 0xbe, 0xff, 0xff, 0xff, 0xff, 
	0xff, 0xa6, 0xff, 0xfb, 0xbf, 0xff, 0xfa, 0xfa, 
	0xef, 0x3f, 0x7f, 0xdd, 0xfd, 0xd6, 0x6f, 0xff, 
	0xbd, 0xf7, 0xdf, 0x7f, 0xff, 0xbf, 0xf9, 0xfe, 
	0x7c, 0xf3, 0xcf, 0x3f, 0xff, 0xfc, 0xf1, 0x87, 
	0x6f, 0xfe, 0xf9, 0xe3, 0x9f, 0x7f, 0xfe, 0xf9, 
	0xe7, 0xff, 0x6f, 0xfe, 0x7f, 0xff, 0xfe, 0xd9, 
	0xde, 0xbd, 0xff, 0xfe, 0xf7, 0xb7, 0xff, 0xfe, 
	0xfd, 0xf7, 0xcf, 0x7f, 0xff, 0xfd, 0xff, 0x9b, 
	0xff, 0xdf, 0x7f, 0xfa, 0xf9, 0xa7, 0xdf, 0x7e, 
	0xfa, 0xf9, 0xef, 0x3f, 0xfd, 0xf6, 0xd3, 0x4f, 
	0x3f, 0xfd, 0xf4, 0xff, 0xe6, 0xfd, 0xdf, 0xdf, 
	0x7f, 0xff, 0xff, 0xd7, 0xdf, 0x7f, 0xff, 0xfb, 
	0xfe, 0xbd, 0xff, 0xfe, 0xfb, 0xef, 0xbe, 0xff, 
	0xbf, 0xf9, 0x7f, 0xfe, 0xff, 0xff, 0xbd, 0xff, 
	0xeb, 0x7f, 0xfd, 0xf7, 0xfb, 0xfc, 0xbf, 0xff, 
	0xff, 0xff, 0xdf, 0xff, 0xff, 0x6f, 0xde, 0xff, 
	0x7b, 0xfd, 0xf7, 0xff, 0x6f, 0xff, 0xfd, 0xf7, 
	0xbe, 0xff, 0xff, 0xfb, 0xef, 0xbf, 0xff, 0xfe, 
	0xfb, 0xff, 0x9b, 0xff, 0xff, 0xff, 0x7f, 0xff, 
	0xf3, 0xff, 0xde, 0xff, 0xff, 0xbf, 0xbf, 0xbb, 
	0xff, 0xfe, 0xff, 0xff, 0xff, 0xff, 0xff, 0xe6, 
	0xff, 0xdf, 0x7f, 0xfd, 0xf9, 0xf7, 0x9f, 0x7f, 
	0xff, 0xfd, 0xef, 0xb7, 0xff, 0xfc, 0xeb, 0xef, 
	0xbf, 0xff, 0xfe, 0xbf, 0xb9, 0xef, 0xb6, 0xdf, 
	0x7e, 0xbb, 0xed, 0xb7, 0xdf, 0x7a, 0xfb, 0xdb, 
	0x6d, 0xbd, 0xfd, 0xf6, 0xdb, 0x6f, 0xbf, 0xfd, 
	0x6f, 0xfe, 0xff, 0xf7, 0xdf, 0x7f, 0xfb, 0xed, 
	0xb7, 0xdf, 0x7f, 0xfb, 0xfb, 0xef, 0xbf, 0xfd, 
	0xfe, 0xfb, 0xef, 0xbf, 0xff, 0x9b, 0xff, 0x7f, 
	0xff, 0xfd, 0xf7, 0xdd, 0x7b, 0xff, 0xfd, 0xf7, 
	0xbe, 0xff, 0xfe, 0xfb, 0xef, 0xbf, 0xff, 0xfe, 
	0xfb, 0xef, 0xe6, 0xff, 0xbf, 0xff, 0xfe, 0xbb, 
	0xef, 0xbf, 0xff, 0xfe, 0xfb, 0xdf, 0x7f, 0xff, 
	0xdd, 0xf7, 0xdf, 0x7f, 0xff, 0xfd, 0xbf, 0xf9, 
	0xff, 0xaf, 0xbf, 0xfe, 0xfa, 0xfb, 0xef, 0xbe, 
	0xfe, 0xfa, 0xd7, 0x5f, 0x7f, 0xfd, 0xfd, 0xd7, 
	0x5f, 0x7f, 0xff, 0x6f, 0xfe, 0xff, 0xfb, 0xef, 
	0xbf, 0xff, 0xfe, 0xfb, 0xef, 0xbf, 0xff, 0xfd, 
	0xf7, 0xdf, 0x7f, 0xff, 0xfd, 0xf7, 0xdf, 0xff, 
	0x9b, 0xff, 0xff, 0xfc, 0xf3, 0xcf, 0x3f, 0xff, 
	0xfc, 0xf3, 0xcf, 0x7f, 0xfe, 0xf9, 0xe7, 0x9f, 
	0x7f, 0xfe, 0xf9, 0xe7, 0xf3, 0xe6, 0xff, 0x5f, 
	0x7f, 0xfd, 0xf5, 0xd7, 0x5f, 0x7f, 0xfd, 0xf5, 
	0xaf, 0xbf, 0xfe, 0xfa, 0xeb, 0xaf, 0xbf, 0xfe, 
	0xfa, 0xbf, 0xf9, 0xff, 0x5f, 0x7f, 0xfd, 0xf5, 
	0xd7, 0x5f, 0x7e, 0xdd, 0xe5, 0x2e, 0xbf, 0xee, 
	0xfa, 0xeb, 0xaf, 0xbf, 0xfe, 0xfa, 0x6f, 0xde, 
	0xff, 0xf6, 0xfb, 0xef, 0xbf, 0xff, 0xda, 0xfb, 
	0x67, 0x57, 0xb9, 0xfd, 0xf5, 0xdf, 0x7e, 0xff, 
	0xfd, 0xd7, 0xff, 0x9b, 0xff, 0xff, 0xff, 0xff, 
	0xff, 0xff, 0xf7, 0xfe, 0xff, 0xff, 0x7f, 0xff, 
	0xff, 0xff, 0xff, 0xfe, 0xff, 0xff, 0xf7, 0xff, 
	0xe6, 0xfe, 0x5f, 0xef, 0xbf, 0xef, 0xbe, 0xff, 
	0xeb, 0xff, 0xf6, 0xbf, 0xf7, 0xff, 0x7e, 0xef, 
	0xed, 0xf7, 0xdf, 0xff, 0xbf, 0xf9, 0xbf, 0x71, 
	0xf7, 0xd7, 0x73, 0xcf, 0x79, 0xf7, 0xb7, 0xff, 
	0xfe, 0xfb, 0xab, 0xaf, 0xbf, 0xfb, 0xfa, 0xfb, 
	0xef, 0x6f, 0xfe, 0xff
};


/* rom names */

#define AFSK_ROM_SWROMIE              0
#define AFSK_ROM_SWROMOE              16


/* rom locations */
static const unsigned long afsk_roms[32] = {
	 45961,  46129,  45629,  45797,  45297,  45465,  44965,  45133,
	 46127,  45963,  45795,  45631,  45463,  45299,  45131,  44967,
	 31023,  30855,  30857,  31021,  31355,  31187,  31189,  31353,
	 31687,  31519,  31521,  31685,  32019,  31851,  31853,  32017
};

